﻿USE PlaceholderForDbName;

DROP PROCEDURE IF EXISTS add_user ;

CREATE PROCEDURE add_user()
BEGIN
DECLARE EXIT HANDLER FOR 1044 BEGIN END;
GRANT ALL PRIVILEGES ON PlaceholderForDbName.* to 'PlaceholderForDbUsername'@'localhost' IDENTIFIED BY 'PlaceholderForDbPassword';
FLUSH PRIVILEGES;
END
;

CALL add_user() ;

DROP PROCEDURE IF EXISTS add_user ;

CREATE TABLE AreaGroupBlockTypes (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
arHandle                 VARCHAR(255) NOT NULL,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
btID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID, arHandle, gID, uID, btID)
);

CREATE TABLE AreaGroups (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
arHandle                 VARCHAR(255) NOT NULL,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
agPermissions            VARCHAR(64) NOT NULL,
                 PRIMARY KEY (cID, arHandle, gID, uID)
);

CREATE TABLE Areas (
arID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
arHandle                 VARCHAR(255) NOT NULL,
arOverrideCollectionPermissions TINYINT(1) NOT NULL DEFAULT 0,
arInheritPermissionsFromAreaOnCID INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (arID)
);

CREATE TABLE AttributeSetKeys (
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
asID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
displayOrder             INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (akID, asID)
);

CREATE TABLE AttributeSets (
asID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
asName                   VARCHAR(255),
asHandle                 VARCHAR(255) NOT NULL,
akCategoryID             INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (asID)
);

CREATE TABLE AttributeKeys (
akID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
akHandle                 VARCHAR(255) NOT NULL,
akName                   VARCHAR(255) NOT NULL,
akIsSearchable           TINYINT(1) NOT NULL DEFAULT 0,
akIsSearchableIndexed    TINYINT(1) NOT NULL DEFAULT 0,
akIsAutoCreated          TINYINT(1) NOT NULL DEFAULT 0,
akIsColumnHeader         TINYINT(1) NOT NULL DEFAULT 0,
akIsEditable             TINYINT(1) NOT NULL DEFAULT 0,
atID                     INTEGER(10) UNSIGNED,
akCategoryID             INTEGER(10) UNSIGNED,
pkgID                    INTEGER(10) UNSIGNED,
                 PRIMARY KEY (akID)
);

ALTER TABLE AttributeKeys ADD  UNIQUE INDEX akHandle  (akHandle, akCategoryID);

CREATE TABLE AttributeKeyCategories (
akCategoryID             INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
akCategoryHandle         VARCHAR(255) NOT NULL,
akCategoryAllowSets      SMALLINT(4) NOT NULL DEFAULT 0,
pkgID                    INTEGER(10) UNSIGNED,
                 PRIMARY KEY (akCategoryID)
);

CREATE TABLE AttributeTypeCategories (
atID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akCategoryID             INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (atID, akCategoryID)
);

CREATE TABLE AttributeTypes (
atID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
atHandle                 VARCHAR(255) NOT NULL,
atName                   VARCHAR(255) NOT NULL,
pkgID                    INTEGER(10) UNSIGNED,
                 PRIMARY KEY (atID)
);

CREATE TABLE AttributeValues (
avID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
akID                     INTEGER(10) UNSIGNED,
avDateAdded              DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
uID                      INTEGER(10) UNSIGNED,
atID                     INTEGER(10) UNSIGNED,
                 PRIMARY KEY (avID)
);

CREATE TABLE BlockRelations (
brID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
bID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
originalBID              INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
relationType             VARCHAR(50) NOT NULL,
                 PRIMARY KEY (brID)
);

CREATE TABLE BlockTypes (
btID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
btHandle                 VARCHAR(32) NOT NULL,
btName                   VARCHAR(128) NOT NULL,
btDescription            TEXT,
btActiveWhenAdded        TINYINT(1) NOT NULL DEFAULT 1,
btCopyWhenPropagate      TINYINT(1) NOT NULL DEFAULT 0,
btIncludeAll             TINYINT(1) NOT NULL DEFAULT 0,
btIsInternal             TINYINT(1) NOT NULL DEFAULT 0,
btInterfaceWidth         INTEGER(10) UNSIGNED NOT NULL DEFAULT 400,
btInterfaceHeight        INTEGER(10) UNSIGNED NOT NULL DEFAULT 400,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (btID)
);

ALTER TABLE BlockTypes ADD  UNIQUE INDEX btHandle  (btHandle);

CREATE TABLE Blocks (
bID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
bName                    VARCHAR(60),
bDateAdded               DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
bDateModified            DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
bFilename                VARCHAR(32),
bIsActive                VARCHAR(1) NOT NULL DEFAULT '1',
btID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED,
                 PRIMARY KEY (bID)
);

CREATE TABLE CollectionAttributeValues (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
avID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID, cvID, akID, avID)
);

CREATE TABLE CollectionVersionBlockPermissions (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 1,
bID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cbgPermissions           VARCHAR(32),
                 PRIMARY KEY (cID, cvID, bID, gID, uID)
);

CREATE TABLE CollectionVersionBlocks (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 1,
bID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
arHandle                 VARCHAR(255) NOT NULL,
cbDisplayOrder           INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
isOriginal               TINYINT(1) NOT NULL DEFAULT '0',
cbOverrideAreaPermissions TINYINT(1) NOT NULL DEFAULT 0,
cbIncludeAll             TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID, cvID, bID, arHandle)
);

ALTER TABLE CollectionVersionBlocks ADD  INDEX cbIncludeAll  (cbIncludeAll);

ALTER TABLE CollectionVersionBlocks ADD  INDEX isOriginal  (isOriginal);

CREATE TABLE CollectionVersionBlockStyles (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
bID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
arHandle                 VARCHAR(255) NOT NULL,
csrID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID, cvID, bID, arHandle)
);

CREATE TABLE CollectionVersionAreaLayouts (
cvalID                   INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
cID                      INTEGER(10) UNSIGNED DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED DEFAULT 0,
arHandle                 VARCHAR(255),
layoutID                 INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
position                 INTEGER(10) DEFAULT 1000,
areaNameNumber           INTEGER(10) UNSIGNED DEFAULT 0,
                 PRIMARY KEY (cvalID)
);

ALTER TABLE CollectionVersionAreaLayouts ADD  INDEX areaLayoutsIndex  (cID, cvID, arHandle);

CREATE TABLE CollectionVersionAreaStyles (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
arHandle                 VARCHAR(255) NOT NULL,
csrID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID, cvID, arHandle)
);

CREATE TABLE CollectionVersions (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 1,
cvName                   TEXT,
cvHandle                 VARCHAR(255),
cvDescription            TEXT,
cvDatePublic             DATETIME,
cvDateCreated            DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
cvComments               VARCHAR(255),
cvIsApproved             TINYINT(1) NOT NULL DEFAULT 0,
cvIsNew                  TINYINT(1) NOT NULL DEFAULT 0,
cvAuthorUID              INTEGER(10) UNSIGNED,
cvApproverUID            INTEGER(10) UNSIGNED,
cvActivateDatetime       DATETIME,
                 PRIMARY KEY (cID, cvID)
);

ALTER TABLE CollectionVersions ADD  INDEX cvIsApproved  (cvIsApproved);

ALTER TABLE CollectionVersions ADD  INDEX cvName  (cvName(128));

CREATE TABLE Collections (
cID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
cDateAdded               DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
cDateModified            DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
cHandle                  VARCHAR(255),
                 PRIMARY KEY (cID)
);

ALTER TABLE Collections ADD  INDEX cDateModified  (cDateModified);

ALTER TABLE Collections ADD  INDEX cDateAdded  (cDateAdded);

CREATE TABLE ComposerDrafts (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cpPublishParentID        INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID)
);

CREATE TABLE ComposerContentLayout (
cclID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
bID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
displayOrder             INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ctID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ccFilename               VARCHAR(128),
                 PRIMARY KEY (cclID)
);

CREATE TABLE Config (
cfKey                    VARCHAR(64) NOT NULL,
timestamp                TIMESTAMP NOT NULL,
cfValue                  LONGTEXT,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cfKey, uID)
);

ALTER TABLE Config ADD  INDEX uID  (uID);

CREATE TABLE DashboardHomepage (
dbhID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
dbhModule                VARCHAR(255) NOT NULL,
dbhDisplayName           VARCHAR(255),
dbhDisplayOrder          INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (dbhID)
);

CREATE TABLE DownloadStatistics (
dsID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
fID                      INTEGER(10) UNSIGNED NOT NULL,
fvID                     INTEGER(10) UNSIGNED NOT NULL,
uID                      INTEGER(10) UNSIGNED NOT NULL,
rcID                     INTEGER(10) UNSIGNED NOT NULL,
timestamp                TIMESTAMP NOT NULL,
                 PRIMARY KEY (dsID)
);

CREATE TABLE FileAttributeValues (
fID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
avID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (fID, fvID, akID, avID)
);

CREATE TABLE FilePermissionFileTypes (
fsID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
extension                VARCHAR(32) NOT NULL,
                 PRIMARY KEY (fsID, gID, uID, extension)
);

CREATE TABLE CustomStylePresets (
cspID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
cspName                  VARCHAR(255) NOT NULL,
csrID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cspID)
);

CREATE TABLE CustomStyleRules (
csrID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
css_id                   VARCHAR(128),
css_class                VARCHAR(128),
css_serialized           TEXT,
css_custom               TEXT,
                 PRIMARY KEY (csrID)
);

CREATE TABLE FilePermissions (
fID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
canRead                  INTEGER(4) NOT NULL DEFAULT 0,
canWrite                 INTEGER(4) NOT NULL DEFAULT 0,
canAdmin                 INTEGER(4) NOT NULL DEFAULT 0,
canSearch                INTEGER(4) NOT NULL DEFAULT 0,
                 PRIMARY KEY (fID, gID, uID)
);

CREATE TABLE TaskPermissionUserGroups (
tpID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
canRead                  INTEGER(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (tpID, gID, uID)
);

CREATE TABLE TaskPermissions (
tpID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
tpHandle                 VARCHAR(255),
tpName                   VARCHAR(255),
tpDescription            TEXT,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (tpID)
);

ALTER TABLE TaskPermissions ADD  UNIQUE INDEX tpHandle  (tpHandle);

CREATE TABLE FileSetPermissions (
fsID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
canRead                  INTEGER(4),
canWrite                 INTEGER(4),
canAdmin                 INTEGER(4),
canAdd                   INTEGER(4),
canSearch                INTEGER(3) UNSIGNED,
                 PRIMARY KEY (fsID, gID, uID)
);

ALTER TABLE FileSetPermissions ADD  INDEX canRead  (canRead);

ALTER TABLE FileSetPermissions ADD  INDEX canWrite  (canWrite);

ALTER TABLE FileSetPermissions ADD  INDEX canAdmin  (canAdmin);

ALTER TABLE FileSetPermissions ADD  INDEX canSearch  (canSearch);

ALTER TABLE FileSetPermissions ADD  INDEX canAdd  (canAdd);

CREATE TABLE FileVersions (
fID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvFilename               VARCHAR(255) NOT NULL,
fvPrefix                 VARCHAR(12),
fvGenericType            INTEGER(3) UNSIGNED NOT NULL DEFAULT 0,
fvSize                   INTEGER(20) UNSIGNED NOT NULL DEFAULT 0,
fvTitle                  VARCHAR(255),
fvDescription            TEXT,
fvTags                   VARCHAR(255),
fvIsApproved             INTEGER(10) UNSIGNED NOT NULL DEFAULT 1,
fvDateAdded              DATETIME,
fvApproverUID            INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvAuthorUID              INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvActivateDatetime       DATETIME,
fvHasThumbnail1          INTEGER(1) NOT NULL DEFAULT 0,
fvHasThumbnail2          INTEGER(1) NOT NULL DEFAULT 0,
fvHasThumbnail3          INTEGER(1) NOT NULL DEFAULT 0,
fvExtension              VARCHAR(32),
fvType                   INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (fID, fvID)
);

ALTER TABLE FileVersions ADD  INDEX fvExtension  (fvType);

ALTER TABLE FileVersions ADD  INDEX fvTitle  (fvTitle);

CREATE TABLE FileVersionLog (
fvlID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
fID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fvUpdateTypeID           INTEGER(3) UNSIGNED NOT NULL DEFAULT 0,
fvUpdateTypeAttributeID  INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (fvlID)
);

CREATE TABLE FileStorageLocations (
fslID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fslName                  VARCHAR(255) NOT NULL,
fslDirectory             VARCHAR(255) NOT NULL,
                 PRIMARY KEY (fslID)
);

CREATE TABLE Files (
fID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
fDateAdded               DATETIME,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fslID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ocID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fOverrideSetPermissions  INTEGER(1) NOT NULL DEFAULT 0,
fPassword                VARCHAR(255),
                 PRIMARY KEY (fID, uID, fslID)
);

ALTER TABLE Files ADD  INDEX fOverrideSetPermissions  (fOverrideSetPermissions);

CREATE TABLE Groups (
gID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
gName                    VARCHAR(128) NOT NULL,
gDescription             VARCHAR(255) NOT NULL,
gUserExpirationIsEnabled INTEGER(1) NOT NULL DEFAULT 0,
gUserExpirationMethod    VARCHAR(12),
gUserExpirationSetDateTime DATETIME,
gUserExpirationInterval  INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gUserExpirationAction    VARCHAR(20),
                 PRIMARY KEY (gID)
);

ALTER TABLE Groups ADD  UNIQUE INDEX gName  (gName);

CREATE TABLE Jobs (
jID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
jName                    VARCHAR(100) NOT NULL,
jDescription             VARCHAR(255) NOT NULL,
jDateInstalled           DATETIME,
jDateLastRun             DATETIME,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
jLastStatusText          VARCHAR(255),
jLastStatusCode          SMALLINT(4) NOT NULL DEFAULT 0,
jStatus                  VARCHAR(14) NOT NULL DEFAULT 'ENABLED',
jHandle                  VARCHAR(255) NOT NULL,
jNotUninstallable        SMALLINT(4) NOT NULL DEFAULT 0,
                 PRIMARY KEY (jID)
);

CREATE TABLE JobsLog (
jlID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
jID                      INTEGER(10) UNSIGNED NOT NULL,
jlMessage                VARCHAR(255) NOT NULL,
jlTimestamp              TIMESTAMP NOT NULL,
jlError                  INTEGER(10) NOT NULL DEFAULT 0,
                 PRIMARY KEY (jlID)
);

CREATE TABLE Layouts (
layoutID                 INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
layout_rows              INTEGER(5) NOT NULL DEFAULT 3,
layout_columns           INTEGER(3) NOT NULL DEFAULT 3,
spacing                  INTEGER(3) NOT NULL DEFAULT 3,
breakpoints              VARCHAR(255) NOT NULL DEFAULT '',
locked                   TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (layoutID)
);

CREATE TABLE LayoutPresets (
lpID                     INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
lpName                   VARCHAR(128) NOT NULL,
layoutID                 INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (lpID)
);

ALTER TABLE LayoutPresets ADD  UNIQUE INDEX layoutID  (layoutID);

CREATE TABLE SystemNotifications (
snID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
snTypeID                 INTEGER(3) UNSIGNED NOT NULL DEFAULT 0,
snURL                    TEXT,
snURL2                   TEXT,
snDateTime               DATETIME NOT NULL,
snIsArchived             INTEGER(1) NOT NULL DEFAULT 0,
snIsNew                  INTEGER(1) NOT NULL DEFAULT 0,
snTitle                  VARCHAR(255),
snDescription            TEXT,
snBody                   TEXT,
                 PRIMARY KEY (snID)
);

CREATE TABLE Packages (
pkgID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
pkgName                  VARCHAR(255) NOT NULL,
pkgHandle                VARCHAR(64) NOT NULL,
pkgDescription           TEXT,
pkgDateInstalled         DATETIME NOT NULL,
pkgIsInstalled           TINYINT(1) NOT NULL DEFAULT 1,
pkgVersion               VARCHAR(32),
pkgAvailableVersion      VARCHAR(32),
                 PRIMARY KEY (pkgID)
);

ALTER TABLE Packages ADD  UNIQUE INDEX pkgHandle  (pkgHandle);

CREATE TABLE PagePaths (
ppID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
cID                      INTEGER(10) UNSIGNED DEFAULT 0,
cPath                    TEXT,
ppIsCanonical            VARCHAR(1) NOT NULL DEFAULT '1',
                 PRIMARY KEY (ppID)
);

ALTER TABLE PagePaths ADD  INDEX cID  (cID);

ALTER TABLE PagePaths ADD  INDEX ppIsCanonical  (ppIsCanonical);

ALTER TABLE PagePaths ADD  INDEX cPath (cPath(128));

CREATE TABLE PageSearchIndex (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
content                  TEXT,
cName                    VARCHAR(255),
cDescription             TEXT,
cPath                    TEXT,
cDatePublic              DATETIME,
cDateLastIndexed         DATETIME,
cDateLastSitemapped      DATETIME,
                 PRIMARY KEY (cID)
)ENGINE=MYISAM;

ALTER TABLE PageSearchIndex ADD  FULLTEXT INDEX cName  (cName);

ALTER TABLE PageSearchIndex ADD  FULLTEXT INDEX cDescription  (cDescription);

ALTER TABLE PageSearchIndex ADD  FULLTEXT INDEX content  (content);

ALTER TABLE PageSearchIndex ADD  FULLTEXT INDEX content2  (cName, cDescription, content);

ALTER TABLE PageSearchIndex ADD  INDEX cDateLastIndexed  (cDateLastIndexed);

ALTER TABLE PageSearchIndex ADD  INDEX cDateLastSitemapped  (cDateLastSitemapped);

CREATE TABLE PagePermissionPageTypes (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ctID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID, gID, uID, ctID)
);

CREATE TABLE PagePermissions (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cgPermissions            VARCHAR(32),
cgStartDate              DATETIME,
cgEndDate                DATETIME,
                 PRIMARY KEY (cID, gID, uID)
);

CREATE TABLE PageStatistics (
pstID                    BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
date                     DATE,
timestamp                TIMESTAMP NOT NULL,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (pstID)
)ENGINE=MYISAM;

ALTER TABLE PageStatistics ADD  INDEX cID  (cID);

ALTER TABLE PageStatistics ADD  INDEX date  (date);

ALTER TABLE PageStatistics ADD  INDEX uID  (uID);

CREATE TABLE PageThemes (
ptID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
ptHandle                 VARCHAR(64) NOT NULL,
ptName                   VARCHAR(255),
ptDescription            TEXT,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (ptID)
);

ALTER TABLE PageThemes ADD  UNIQUE INDEX ptHandle  (ptHandle);

CREATE TABLE PageThemeStyles (
ptID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ptsHandle                VARCHAR(128) NOT NULL,
ptsValue                 LONGTEXT,
ptsType                  VARCHAR(32) NOT NULL,
                 PRIMARY KEY (ptID, ptsHandle, ptsType)
);

CREATE TABLE PageTypeAttributes (
ctID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (ctID, akID)
);


CREATE TABLE PageTypes (
ctID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
ctHandle                 VARCHAR(32) NOT NULL,
ctIcon                   VARCHAR(128),
ctName                   VARCHAR(90) NOT NULL,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (ctID)
);

ALTER TABLE PageTypes ADD  UNIQUE INDEX ctHandle  (ctHandle);

CREATE TABLE ComposerTypes (
ctID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ctComposerPublishPageMethod VARCHAR(64) NOT NULL DEFAULT 'CHOOSE',
ctComposerPublishPageTypeID INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ctComposerPublishPageParentID INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (ctID)
);

CREATE TABLE Pages (
cID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ctID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cIsTemplate              TINYINT(1) NOT NULL DEFAULT '0',
uID                      INTEGER(10) UNSIGNED,
cIsCheckedOut            TINYINT(1) NOT NULL DEFAULT 0,
cCheckedOutUID           INTEGER(10) UNSIGNED,
cCheckedOutDatetime      DATETIME,
cCheckedOutDatetimeLastEdit DATETIME,
cPendingAction           VARCHAR(6),
cPendingActionDatetime   DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
cPendingActionUID        INTEGER(10) UNSIGNED,
cPendingActionTargetCID  INTEGER(10) UNSIGNED,
cOverrideTemplatePermissions TINYINT(1) NOT NULL DEFAULT 1,
cInheritPermissionsFromCID INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cInheritPermissionsFrom  VARCHAR(8) NOT NULL DEFAULT 'PARENT',
cFilename                VARCHAR(255),
cPointerID               INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cPointerExternalLink     VARCHAR(255),
cPointerExternalLinkNewWindow TINYINT(1) NOT NULL DEFAULT 0,
cChildren                INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cDisplayOrder            INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cParentID                INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
pkgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ptID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
cCacheFullPageContent    INTEGER(4) NOT NULL DEFAULT -1,
cCacheFullPageContentOverrideLifetime VARCHAR(32) NOT NULL DEFAULT '0',
cCacheFullPageContentLifetimeCustom INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (cID)
);

ALTER TABLE Pages ADD  INDEX cParentID  (cParentID);

ALTER TABLE Pages ADD  INDEX cCheckedOutUID  (cCheckedOutUID);

ALTER TABLE Pages ADD  INDEX cPointerID  (cPointerID);

ALTER TABLE Pages ADD  INDEX uID  (uID);

ALTER TABLE Pages ADD  INDEX ctID  (ctID);

ALTER TABLE Pages ADD INDEX cIsTemplate (cIsTemplate);

CREATE TABLE PileContents (
pcID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
pID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
itemID                   INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
itemType                 VARCHAR(64) NOT NULL,
quantity                 INTEGER(10) UNSIGNED NOT NULL DEFAULT 1,
timestamp                TIMESTAMP NOT NULL,
displayOrder             INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (pcID)
);

CREATE TABLE Piles (
pID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
uID                      INTEGER(10) UNSIGNED,
isDefault                TINYINT(1) NOT NULL DEFAULT 0,
timestamp                TIMESTAMP NOT NULL,
name                     VARCHAR(255),
state                    VARCHAR(64) NOT NULL,
                 PRIMARY KEY (pID)
);

CREATE TABLE UserAttributeKeys (
akID                     INTEGER(10) UNSIGNED NOT NULL,
uakProfileDisplay        TINYINT(1) NOT NULL DEFAULT 0,
uakMemberListDisplay     TINYINT(1) NOT NULL DEFAULT 0,
uakProfileEdit           TINYINT(1) NOT NULL DEFAULT 1,
uakProfileEditRequired   TINYINT(1) NOT NULL DEFAULT 0,
uakRegisterEdit          TINYINT(1) NOT NULL DEFAULT 0,
uakRegisterEditRequired  TINYINT(1) NOT NULL DEFAULT 0,
displayOrder             INTEGER(10) UNSIGNED DEFAULT 0,
uakIsActive              TINYINT(1) NOT NULL DEFAULT 1,
                 PRIMARY KEY (akID)
);

CREATE TABLE UserAttributeValues (
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
avID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (uID, akID, avID)
);

CREATE TABLE UserPrivateMessages (
msgID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
uAuthorID                INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
msgDateCreated           DATETIME NOT NULL,
msgSubject               VARCHAR(255) NOT NULL,
msgBody                  TEXT,
uToID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (msgID)
);

CREATE TABLE UserPrivateMessagesTo (
msgID                    INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uAuthorID                INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
msgMailboxID             INTEGER(11) NOT NULL,
msgIsNew                 INTEGER(1) NOT NULL DEFAULT 0,
msgIsUnread              INTEGER(1) NOT NULL DEFAULT 0,
msgIsReplied             INTEGER(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (msgID, uID, uAuthorID)
);

ALTER TABLE UserPrivateMessagesTo ADD  INDEX uID  (uID);

ALTER TABLE UserPrivateMessagesTo ADD  INDEX uAuthorID  (uAuthorID);

ALTER TABLE UserPrivateMessagesTo ADD  INDEX msgFolderID  (msgMailboxID);

ALTER TABLE UserPrivateMessagesTo ADD  INDEX msgIsNew  (msgIsNew);

CREATE TABLE UserBannedIPs (
ipFrom                   INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ipTo                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
banCode                  INTEGER(1) UNSIGNED NOT NULL DEFAULT 1,
expires                  INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
isManual                 INTEGER(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (ipFrom, ipTo)
);

ALTER TABLE UserBannedIPs ADD  INDEX ipFrom  (ipFrom);

ALTER TABLE UserBannedIPs ADD  INDEX ipTo  (ipTo);

CREATE TABLE UserGroups (
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
gID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
ugEntered                DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
type                     VARCHAR(64),
                 PRIMARY KEY (uID, gID)
);

ALTER TABLE UserGroups ADD  INDEX uID  (uID);

ALTER TABLE UserGroups ADD  INDEX gID  (gID);

CREATE TABLE UserValidationHashes (
uvhID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
uID                      INTEGER(10) UNSIGNED,
uHash                    VARCHAR(64) NOT NULL,
type                     INTEGER(4) UNSIGNED NOT NULL DEFAULT 0,
uDateGenerated           INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uDateRedeemed            INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (uvhID)
);

CREATE TABLE Logs (
logID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
logType                  VARCHAR(64) NOT NULL,
timestamp                TIMESTAMP NOT NULL,
logText                  LONGTEXT,
logIsInternal            TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (logID)
);

ALTER TABLE Logs ADD  INDEX logType  (logType);

ALTER TABLE Logs ADD  INDEX logIsInternal  (logIsInternal);

CREATE TABLE MailImporters (
miID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
miHandle                 VARCHAR(64) NOT NULL,
miServer                 VARCHAR(255),
miUsername               VARCHAR(255),
miPassword               VARCHAR(255),
miEncryption             VARCHAR(32),
miIsEnabled              INTEGER(1) NOT NULL DEFAULT 0,
miEmail                  VARCHAR(255),
miPort                   INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
pkgID                    INTEGER(10) UNSIGNED,
                 PRIMARY KEY (miID)
);

CREATE TABLE MailValidationHashes (
mvhID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
miID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
email                    VARCHAR(255) NOT NULL,
mHash                    VARCHAR(128) NOT NULL,
mDateGenerated           INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
mDateRedeemed            INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
data                     TEXT,
                 PRIMARY KEY (mvhID)
);

CREATE TABLE UserOpenIDs (
uID                      INTEGER(10) UNSIGNED NOT NULL,
uOpenID                  VARCHAR(255) NOT NULL,
                 PRIMARY KEY (uOpenID)
);

ALTER TABLE UserOpenIDs ADD  INDEX uID  (uID);

CREATE TABLE Users (
uID                      INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
uName                    VARCHAR(64) NOT NULL,
uEmail                   VARCHAR(64) NOT NULL,
uPassword                VARCHAR(255) NOT NULL,
uIsActive                VARCHAR(1) NOT NULL DEFAULT '0',
uIsValidated             TINYINT NOT NULL DEFAULT -1,
uIsFullRecord            TINYINT(1) NOT NULL DEFAULT 1,
uDateAdded               DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
uHasAvatar               TINYINT(1) NOT NULL DEFAULT 0,
uLastOnline              INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uLastLogin               INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uPreviousLogin           INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uNumLogins               INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
uTimezone                VARCHAR(255),
uDefaultLanguage		 VARCHAR(32) NULL,
                 PRIMARY KEY (uID)
);

ALTER TABLE Users ADD  UNIQUE INDEX uName  (uName);

CREATE TABLE UsersFriends (
ufID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
uID                      INTEGER(10) UNSIGNED,
status                   VARCHAR(64) NOT NULL,
friendUID                INTEGER(10) UNSIGNED,
uDateAdded               DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
                 PRIMARY KEY (ufID)
);

CREATE TABLE SignupRequests (
id                       INTEGER(11) NOT NULL AUTO_INCREMENT,
ipFrom                   INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
date_access              TIMESTAMP NOT NULL,
                 PRIMARY KEY (id)
);

ALTER TABLE SignupRequests ADD  INDEX index_ipFrom  (ipFrom);

CREATE TABLE FileSets (
fsID                     INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
fsName                   VARCHAR(64) NOT NULL,
uID                      INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fsType                   INTEGER(4) NOT NULL,
fsOverrideGlobalPermissions INTEGER(4),
                 PRIMARY KEY (fsID)
);

ALTER TABLE FileSets ADD  INDEX fsOverrideGlobalPermissions  (fsOverrideGlobalPermissions);

CREATE TABLE FileSetSavedSearches (
fsID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
fsSearchRequest          TEXT,
fsResultColumns          TEXT,
                 PRIMARY KEY (fsID)
);

CREATE TABLE FileSetFiles (
fsfID                    INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
fID                      INTEGER(10) UNSIGNED NOT NULL,
fsID                     INTEGER(10) UNSIGNED NOT NULL,
timestamp                TIMESTAMP NOT NULL,
fsDisplayOrder           INTEGER(10) UNSIGNED NOT NULL,
                 PRIMARY KEY (fsfID)
);

ALTER TABLE FileSetFiles ADD  INDEX fID  (fID);

ALTER TABLE FileSetFiles ADD  INDEX fsID  (fsID);

CREATE TABLE atBoolean (
avID                     INTEGER(10) UNSIGNED NOT NULL,
value                    TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (avID)
);

CREATE TABLE atBooleanSettings (
akID                     INTEGER(10) UNSIGNED NOT NULL,
akCheckedByDefault       TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (akID)
);

CREATE TABLE atDateTimeSettings (
akID                     INTEGER(10) UNSIGNED NOT NULL,
akDateDisplayMode        VARCHAR(255),
                 PRIMARY KEY (akID)
);

CREATE TABLE atDateTime (
avID                     INTEGER(10) UNSIGNED NOT NULL,
value                    DATETIME DEFAULT '0000-00-00 00:00:00',
                 PRIMARY KEY (avID)
);

CREATE TABLE atDefault (
avID                     INTEGER(10) UNSIGNED NOT NULL,
value                    LONGTEXT,
                 PRIMARY KEY (avID)
);

CREATE TABLE atFile (
avID                     INTEGER(10) UNSIGNED NOT NULL,
fID                      INTEGER(10) UNSIGNED NOT NULL,
                 PRIMARY KEY (avID)
);

CREATE TABLE atNumber (
avID                     INTEGER(10) UNSIGNED NOT NULL,
value                    NUMERIC(14,4) DEFAULT 0,
                 PRIMARY KEY (avID)
);

CREATE TABLE atSelectSettings (
akID                     INTEGER(10) UNSIGNED NOT NULL,
akSelectAllowMultipleValues TINYINT(1) NOT NULL DEFAULT 0,
akSelectOptionDisplayOrder VARCHAR(255) NOT NULL DEFAULT 'display_asc',
akSelectAllowOtherValues TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (akID)
);

CREATE TABLE atTextareaSettings (
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akTextareaDisplayMode    VARCHAR(255),
                 PRIMARY KEY (akID)
);

CREATE TABLE atSelectOptions (
ID                       INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
akID                     INTEGER(10) UNSIGNED,
value                    VARCHAR(255),
displayOrder             INTEGER(10) UNSIGNED,
isEndUserAdded           TINYINT(1) NOT NULL DEFAULT 0,
                 PRIMARY KEY (ID)
);

CREATE TABLE atSelectOptionsSelected (
avID                     INTEGER(10) UNSIGNED NOT NULL,
atSelectOptionID         INTEGER(10) UNSIGNED NOT NULL,
                 PRIMARY KEY (avID, atSelectOptionID)
);

ALTER TABLE atSelectOptionsSelected add index `atSelectOptionID` (atSelectOptionID);

CREATE TABLE atAddress (
avID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
address1                 VARCHAR(255),
address2                 VARCHAR(255),
city                     VARCHAR(255),
state_province           VARCHAR(255),
country                  VARCHAR(4),
postal_code              VARCHAR(32),
                 PRIMARY KEY (avID)
);

CREATE TABLE atAddressCustomCountries (
atAddressCustomCountryID INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
country                  VARCHAR(5) NOT NULL,
                 PRIMARY KEY (atAddressCustomCountryID)
);

CREATE TABLE atAddressSettings (
akID                     INTEGER(10) UNSIGNED NOT NULL DEFAULT 0,
akHasCustomCountries     INTEGER(1) NOT NULL DEFAULT 0,
akDefaultCountry         VARCHAR(12),
                 PRIMARY KEY (akID)
);

CREATE TABLE btNavigation (
bID                      INTEGER UNSIGNED NOT NULL,
orderBy                  VARCHAR(255) DEFAULT 'alpha_asc',
displayPages             VARCHAR(255) DEFAULT 'top',
displayPagesCID          INTEGER UNSIGNED NOT NULL DEFAULT 1,
displayPagesIncludeSelf  TINYINT UNSIGNED NOT NULL DEFAULT 0,
displaySubPages          VARCHAR(255) DEFAULT 'none',
displaySubPageLevels     VARCHAR(255) DEFAULT 'none',
displaySubPageLevelsNum  SMALLINT UNSIGNED NOT NULL DEFAULT 0,
displayUnavailablePages  TINYINT UNSIGNED NOT NULL DEFAULT 0,
                 PRIMARY KEY (bID)
);

CREATE TABLE btContentLocal (
bID                      INTEGER UNSIGNED NOT NULL,
content                  LONGTEXT,
                 PRIMARY KEY (bID)
);

CREATE TABLE btDateNav (
bID                      INTEGER UNSIGNED NOT NULL,
num                      SMALLINT UNSIGNED NOT NULL,
cParentID                INTEGER UNSIGNED NOT NULL DEFAULT 1,
cThis                    TINYINT UNSIGNED NOT NULL DEFAULT 0,
ctID                     SMALLINT UNSIGNED,
flatDisplay              INTEGER DEFAULT 0,
defaultNode              VARCHAR(64) DEFAULT 'current_page',
truncateTitles           INTEGER DEFAULT 0,
truncateSummaries        INTEGER DEFAULT 0,
displayFeaturedOnly      INTEGER DEFAULT 0,
truncateChars            INTEGER DEFAULT 128,
truncateTitleChars       INTEGER DEFAULT 128,
showDescriptions         INTEGER DEFAULT 0,
                 PRIMARY KEY (bID)
);

CREATE TABLE btExternalForm (
bID                      INTEGER UNSIGNED NOT NULL,
filename                 VARCHAR(128),
                 PRIMARY KEY (bID)
);

CREATE TABLE btContentFile (
bID                      INTEGER UNSIGNED NOT NULL,
fID                      INTEGER UNSIGNED,
fileLinkText             VARCHAR(255),
filePassword             VARCHAR(255),
                 PRIMARY KEY (bID)
);

CREATE TABLE btFlashContent (
bID                      INTEGER UNSIGNED NOT NULL,
fID                      INTEGER UNSIGNED,
quality                  VARCHAR(255),
minVersion               VARCHAR(255),
                 PRIMARY KEY (bID)
);

CREATE TABLE btForm (
bID                      INTEGER UNSIGNED NOT NULL,
questionSetId            INTEGER UNSIGNED DEFAULT 0,
surveyName               VARCHAR(255),
thankyouMsg              TEXT,
notifyMeOnSubmission     TINYINT UNSIGNED NOT NULL DEFAULT 0,
recipientEmail           VARCHAR(255),
displayCaptcha           INTEGER DEFAULT 1,
redirectCID              INTEGER DEFAULT 0,
                 PRIMARY KEY (bID)
);

ALTER TABLE btForm ADD  INDEX questionSetIdForeign  (questionSetId);

CREATE TABLE btFormQuestions (
qID                      INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
msqID                    INTEGER UNSIGNED DEFAULT 0,
bID                      INTEGER UNSIGNED DEFAULT 0,
questionSetId            INTEGER UNSIGNED DEFAULT 0,
question                 VARCHAR(255),
inputType                VARCHAR(255),
options                  TEXT,
position                 INTEGER UNSIGNED DEFAULT 1000,
width                    INTEGER UNSIGNED DEFAULT 50,
height                   INTEGER UNSIGNED DEFAULT 3,
required                 INTEGER DEFAULT 0,
                 PRIMARY KEY (qID)
);

ALTER TABLE btFormQuestions ADD  INDEX questionSetId  (questionSetId);

ALTER TABLE btFormQuestions ADD  INDEX msqID  (msqID);

CREATE TABLE btFormAnswerSet (
asID                     INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
questionSetId            INTEGER UNSIGNED DEFAULT 0,
created                  TIMESTAMP,
uID                      INTEGER UNSIGNED DEFAULT 0,
                 PRIMARY KEY (asID)
);

CREATE TABLE btFormAnswers (
aID                      INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
asID                     INTEGER UNSIGNED DEFAULT 0,
msqID                    INTEGER UNSIGNED DEFAULT 0,
answer                   VARCHAR(255),
answerLong               TEXT,
                 PRIMARY KEY (aID)
);

CREATE TABLE btGoogleMap (
bID                      INTEGER UNSIGNED NOT NULL,
title                    VARCHAR(255),
location                 VARCHAR(255),
latitude                 DOUBLE,
longitude                DOUBLE,
zoom                     INTEGER(8),
                 PRIMARY KEY (bID)
);

CREATE TABLE btGuestBook (
bID                      INTEGER UNSIGNED NOT NULL,
requireApproval          INTEGER DEFAULT 0,
title                    VARCHAR(100) DEFAULT 'Comments',
dateFormat               VARCHAR(100),
displayGuestBookForm     INTEGER DEFAULT 1,
displayCaptcha           INTEGER DEFAULT 1,
authenticationRequired   INTEGER DEFAULT 0,
notifyEmail              VARCHAR(100),
                 PRIMARY KEY (bID)
);

CREATE TABLE btGuestBookEntries (
bID                      INTEGER,
cID                      INTEGER DEFAULT 1,
entryID                  INTEGER NOT NULL AUTO_INCREMENT,
uID                      INTEGER DEFAULT 0,
commentText              LONGTEXT,
user_name                VARCHAR(100),
user_email               VARCHAR(100),
entryDate                TIMESTAMP,
approved                 INTEGER DEFAULT 1,
                 PRIMARY KEY (entryID)
);

ALTER TABLE btGuestBookEntries ADD  INDEX cID  (cID);

CREATE TABLE btContentImage (
bID                      INTEGER UNSIGNED NOT NULL,
fID                      INTEGER UNSIGNED DEFAULT 0,
fOnstateID               INTEGER UNSIGNED DEFAULT 0,
maxWidth                 INTEGER UNSIGNED DEFAULT 0,
maxHeight                INTEGER UNSIGNED DEFAULT 0,
externalLink             VARCHAR(255),
altText                  VARCHAR(255),
                 PRIMARY KEY (bID)
);

CREATE TABLE btFile (
bID                      INTEGER UNSIGNED NOT NULL,
filename                 VARCHAR(255),
origfilename             VARCHAR(255),
url                      VARCHAR(255),
type                     VARCHAR(32),
generictype              VARCHAR(32),
                 PRIMARY KEY (bID)
);

CREATE TABLE btNextPrevious (
bID                      INTEGER UNSIGNED NOT NULL,
linkStyle                VARCHAR(32),
nextLabel                VARCHAR(128),
previousLabel            VARCHAR(128),
parentLabel              VARCHAR(128),
showArrows               INTEGER DEFAULT 1,
loopSequence             INTEGER DEFAULT 1,
excludeSystemPages       INTEGER DEFAULT 1,
orderBy                  VARCHAR(20) DEFAULT 'display_asc',
                 PRIMARY KEY (bID)
);

CREATE TABLE btPageList (
bID                      INTEGER UNSIGNED NOT NULL,
num                      SMALLINT UNSIGNED NOT NULL,
orderBy                  VARCHAR(32),
cParentID                INTEGER UNSIGNED NOT NULL DEFAULT 1,
cThis                    TINYINT UNSIGNED NOT NULL DEFAULT 0,
paginate                 TINYINT UNSIGNED NOT NULL DEFAULT 0,
displayAliases           TINYINT UNSIGNED NOT NULL DEFAULT 1,
ctID                     SMALLINT UNSIGNED,
rss                      INTEGER DEFAULT 0,
rssTitle                 VARCHAR(255),
rssDescription           LONGTEXT,
truncateSummaries        INTEGER DEFAULT 0,
displayFeaturedOnly      INTEGER DEFAULT 0,
truncateChars            INTEGER DEFAULT 128,
                 PRIMARY KEY (bID)
);

CREATE TABLE btRssDisplay (
bID                      INTEGER UNSIGNED NOT NULL,
title                    VARCHAR(255),
url                      VARCHAR(255),
dateFormat               VARCHAR(100),
itemsToDisplay           INTEGER UNSIGNED DEFAULT 5,
showSummary              TINYINT UNSIGNED NOT NULL DEFAULT 1,
launchInNewWindow        TINYINT UNSIGNED NOT NULL DEFAULT 1,
                 PRIMARY KEY (bID)
);

CREATE TABLE btSearch (
bID                      INTEGER UNSIGNED NOT NULL,
title                    VARCHAR(255),
buttonText               VARCHAR(128),
baseSearchPath           VARCHAR(255),
resultsURL               VARCHAR(255),
                 PRIMARY KEY (bID)
);

CREATE TABLE btSlideshow (
bID                      INTEGER UNSIGNED NOT NULL,
fsID                     INTEGER UNSIGNED,
playback                 VARCHAR(50),
duration                 INTEGER UNSIGNED,
fadeDuration             INTEGER UNSIGNED,
                 PRIMARY KEY (bID)
);

CREATE TABLE btSlideshowImg (
slideshowImgId           INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
bID                      INTEGER UNSIGNED,
fID                      INTEGER UNSIGNED,
url                      VARCHAR(255),
duration                 INTEGER UNSIGNED,
fadeDuration             INTEGER UNSIGNED,
groupSet                 INTEGER UNSIGNED,
position                 INTEGER UNSIGNED,
imgHeight                INTEGER UNSIGNED,
                 PRIMARY KEY (slideshowImgId)
);

CREATE TABLE btSurvey (
bID                      INTEGER UNSIGNED NOT NULL,
question                 VARCHAR(255) DEFAULT '',
requiresRegistration     INTEGER DEFAULT 0,
                 PRIMARY KEY (bID)
);

CREATE TABLE btSurveyOptions (
optionID                 INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
bID                      INTEGER,
optionName               VARCHAR(255),
displayOrder             INTEGER DEFAULT 0,
                 PRIMARY KEY (optionID)
);

CREATE TABLE btSurveyResults (
resultID                 INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
optionID                 INTEGER UNSIGNED DEFAULT 0,
uID                      INTEGER UNSIGNED DEFAULT 0,
bID                      INTEGER,
cID                      INTEGER,
ipAddress                VARCHAR(128),
timestamp                TIMESTAMP,
                 PRIMARY KEY (resultID)
);

CREATE TABLE btTags (
bID                      INTEGER UNSIGNED NOT NULL,
title                    VARCHAR(255),
targetCID                INTEGER,
displayMode              VARCHAR(20) DEFAULT 'page',
cloudCount               INTEGER DEFAULT 10,
                 PRIMARY KEY (bID)
);

CREATE TABLE btVideo (
bID                      INTEGER UNSIGNED NOT NULL,
fID                      INTEGER UNSIGNED,
width                    INTEGER UNSIGNED,
height                   INTEGER UNSIGNED,
                 PRIMARY KEY (bID)
);

CREATE TABLE `btYouTube` (
  `bID` int(10) unsigned NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `videoURL` varchar(255) DEFAULT NULL,
  `vHeight` varchar(255) DEFAULT NULL,
  `vWidth` varchar(255) DEFAULT NULL,
  `vPlayer` tinyint(3) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`bID`)
);

CREATE TABLE IF NOT EXISTS `CollectionSearchIndexAttributes` (
  `cID` int(11) unsigned NOT NULL default '0',
  `ak_meta_title` text,
  `ak_meta_description` text,
  `ak_meta_keywords` text,
  `ak_exclude_nav` tinyint(4) default '0',
  `ak_exclude_page_list` tinyint(4) default '0',
  `ak_header_extra_content` text,
  `ak_exclude_search_index` tinyint(4) default '0',
  `ak_exclude_sitemapxml` tinyint(4) default '0',
  `ak_tags` text,
  PRIMARY KEY  (`cID`)
) ENGINE=MyISAM;

CREATE TABLE IF NOT EXISTS `FileSearchIndexAttributes` (
  `fID` int(11) unsigned NOT NULL default '0',
  `ak_width` decimal(14,4) default '0.0000',
  `ak_height` decimal(14,4) default '0.0000',
  PRIMARY KEY  (`fID`)
) ENGINE=MyISAM;

CREATE TABLE IF NOT EXISTS `UserSearchIndexAttributes` (
  `uID` int(11) unsigned NOT NULL DEFAULT '0',
  `ak_profile_private_messages_enabled` tinyint(4) DEFAULT '0',
  `ak_profile_private_messages_notification_enabled` tinyint(4) DEFAULT '0',
  PRIMARY KEY (`uID`)
) ENGINE=MyISAM;

INSERT INTO Areas VALUES(1,1,'Header Nav',0,0)
 ,(2,1,'Header',0,0)
 ,(3,1,'Sidebar',0,0)
 ,(4,1,'Main',0,0)
 ,(5,2,'Header Nav',0,0)
 ,(6,2,'Header',0,0)
 ,(7,2,'Sidebar',0,0)
 ,(8,2,'Main',0,0)
 ,(9,64,'Header Nav',0,0)
 ,(10,64,'Header',0,0)
 ,(11,64,'Sidebar',0,0)
 ,(12,64,'Main',0,0)
 ,(13,65,'Header Nav',0,0)
 ,(14,65,'Header',0,0)
 ,(15,65,'Main',0,0)
 ,(16,66,'Blog Post Header',0,0)
 ,(17,66,'Main',0,0)
 ,(18,66,'Blog Post More',0,0)
 ,(19,66,'Blog Post Footer',0,0)
 ,(20,66,'Header Nav',0,0)
 ,(21,66,'Header',0,0)
 ,(22,66,'Sidebar',0,0)
 ,(23,67,'Header Nav',0,0)
 ,(24,67,'Header',0,0)
 ,(25,67,'Sidebar',0,0)
 ,(26,67,'Main',0,0)
 ,(27,68,'Header Nav',0,0)
 ,(28,68,'Header',0,0)
 ,(29,68,'Sidebar',0,0)
 ,(30,68,'Main',0,0)
 ,(31,69,'Header Nav',0,0)
 ,(32,69,'Header',0,0)
 ,(33,69,'Sidebar',0,0)
 ,(34,69,'Main',0,0)
 ,(35,70,'Header Nav',0,0)
 ,(36,70,'Header',0,0)
 ,(37,70,'Sidebar',0,0)
 ,(38,70,'Main',0,0)
 ,(39,71,'Header Nav',0,0)
 ,(40,71,'Header',0,0)
 ,(41,71,'Sidebar',0,0)
 ,(42,71,'Main',0,0)
 ,(43,72,'Header Nav',0,0)
 ,(44,72,'Header',0,0)
 ,(45,72,'Blog Post Header',0,0)
 ,(46,72,'Main',0,0)
 ,(47,72,'Blog Post More',0,0)
 ,(48,72,'Blog Post Footer',0,0)
 ,(49,72,'Sidebar',0,0)
 ,(50,13,'Main',0,0)
 ,(51,73,'Header Nav',0,0)
 ,(52,73,'Header',0,0)
 ,(53,73,'Blog Post Header',0,0)
 ,(54,73,'Main',0,0)
 ,(55,73,'Blog Post More',0,0)
 ,(56,73,'Blog Post Footer',0,0)
 ,(57,73,'Sidebar',0,0)
 ,(58,36,'Global',0,0);

INSERT INTO AttributeKeyCategories VALUES(1,'collection',0,NULL)
 ,(2,'user',0,NULL)
 ,(3,'file',0,NULL);

INSERT INTO AttributeKeys VALUES(1,'meta_title','Metaタグタイトル',1,0,0,0,1,1,1,0)
 ,(2,'meta_description','Metaタグ説明',1,0,0,0,1,2,1,0)
 ,(3,'meta_keywords','Metaタグキーワード',1,0,0,0,1,2,1,0)
 ,(4,'exclude_nav','オートナビから除く',1,0,0,0,1,3,1,0)
 ,(5,'exclude_page_list','ページリストから除く',1,0,0,0,1,3,1,0)
 ,(6,'header_extra_content','追加ヘッダー要素',1,0,0,0,1,2,1,0)
 ,(7,'exclude_search_index','検索インデックスから除',1,0,0,0,1,3,1,0)
 ,(8,'exclude_sitemapxml','sitemap.xmlから除く',1,0,0,0,1,3,1,0)
 ,(9,'width','横',1,0,1,0,0,6,3,0)
 ,(10,'height','高さ',1,0,1,0,0,6,3,0)
 ,(11,'tags','タグ',0,0,0,0,1,8,1,0)
 ,(12,'profile_private_messages_enabled','プライベートメッセージを受け取る',1,0,0,0,1,3,2,0)
 ,(13,'profile_private_messages_notification_enabled','プライベートメッセージを受け取った時にメール通知を受け取る',1,0,0,0,1,3,2,0);

INSERT INTO UserAttributeKeys VALUES (12,0,0,1,0,1,0,0,1)
 ,(13,0,0,1,0,1,0,1,1);

INSERT INTO AttributeTypeCategories VALUES(1,1)
 ,(1,2)
 ,(1,3)
 ,(2,1)
 ,(2,2)
 ,(2,3)
 ,(3,1)
 ,(3,2)
 ,(3,3)
 ,(4,1)
 ,(4,2)
 ,(4,3)
 ,(5,1)
 ,(6,1)
 ,(6,2)
 ,(6,3)
 ,(7,1)
 ,(7,3)
 ,(8,1)
 ,(8,2)
 ,(8,3)
 ,(9,2);

INSERT INTO AttributeTypes VALUES(1,'text','テキスト',0)
 ,(2,'textarea','テキストエリア（複数行）',0)
 ,(3,'boolean','チェックボックス',0)
 ,(4,'date_time','日付/時刻',0)
 ,(5,'image_file','ファイル/画像',0)
 ,(6,'number','数字',0)
 ,(7,'rating','評価',0)
 ,(8,'select','選択',0)
 ,(9,'address','住所',0);

INSERT INTO AttributeValues VALUES(1,9,NOW(),1,6)
 ,(2,10,NOW(),1,6)
 ,(3,9,NOW(),1,6)
 ,(4,10,NOW(),1,6)
 ,(5,9,NOW(),1,6)
 ,(6,10,NOW(),1,6)
 ,(7,9,NOW(),1,6)
 ,(8,10,NOW(),1,6)
 ,(9,9,NOW(),1,6)
 ,(10,10,NOW(),1,6)
 ,(11,1,NOW(),1,1)
 ,(12,2,NOW(),1,2)
 ,(13,3,NOW(),1,2)
 ,(14,4,NOW(),1,3)
 ,(15,1,NOW(),1,1)
 ,(16,2,NOW(),1,2)
 ,(17,3,NOW(),1,2)
 ,(18,4,NOW(),1,3)
 ,(19,11,NOW(),1,8)
 ,(20,1,NOW(),1,1)
 ,(21,2,NOW(),1,2)
 ,(22,3,NOW(),1,2)
 ,(23,4,NOW(),1,3)
 ,(24,1,NOW(),1,1)
 ,(25,2,NOW(),1,2)
 ,(26,3,NOW(),1,2)
 ,(27,4,NOW(),1,3)
 ,(28,1,NOW(),1,1)
 ,(29,2,NOW(),1,2)
 ,(30,3,NOW(),1,2)
 ,(31,4,NOW(),1,3)
 ,(32,1,NOW(),1,1)
 ,(33,2,NOW(),1,2)
 ,(34,3,NOW(),1,2)
 ,(35,4,NOW(),1,3)
 ,(36,1,NOW(),1,1)
 ,(37,2,NOW(),1,2)
 ,(38,3,NOW(),1,2)
 ,(39,4,NOW(),1,3)
 ,(40,11,NOW(),1,8)
 ,(41,1,NOW(),1,1)
 ,(42,2,NOW(),1,2)
 ,(43,3,NOW(),1,2)
 ,(44,4,NOW(),1,3)
 ,(45,11,NOW(),1,8);

INSERT INTO BlockRelations VALUES(1,31,15,'DUPLICATE')
 ,(2,32,16,'DUPLICATE')
 ,(3,33,23,'DUPLICATE')
 ,(4,34,31,'DUPLICATE')
 ,(5,35,32,'DUPLICATE')
 ,(6,36,15,'DUPLICATE')
 ,(7,39,23,'DUPLICATE');

INSERT INTO BlockTypes VALUES(1,'content','記事','HTML/WYSIWYGエディター付テキストブロックです。',1,0,0,0,600,465,0)
 ,(2,'html','HTMLコード','HTMLのコードを直接追加。',1,0,0,0,600,465,0)
 ,(3,'autonav','オートナビ','ナビゲーションツリーやサイトマップを作成します。',1,0,0,0,500,350,0)
 ,(4,'external_form','外部フォーム','外部で作成されたフォームスクリプトをページに埋め込みます。',1,0,0,0,300,200,0)
 ,(5,'form','フォーム','シンプルなフォームやアンケートを作成します。結果はログに保存、メール通知機能も。',1,0,0,0,420,430,0)
 ,(6,'page_list','ページリスト','タイプやエリアで指定した範囲のページのリストを表示します。',1,0,0,0,500,350,0)
 ,(7,'file','ファイル','ライブラリに保存されたファイルにリンクします。（ダウンロード用）',1,0,0,0,300,250,0)
 ,(8,'image','画像','ライブラリに保存された画像とマウスオーバー画像を表示します。',1,0,0,0,300,440,0)
 ,(9,'flash_content','Flashコンテンツ','Flashファイルをページに組み込みます。',1,0,0,0,300,240,0)
 ,(10,'guestbook','ゲストブック','ブログにあるようなユーザーがコメントを残せるブロックです。',1,0,1,0,300,260,0)
 ,(11,'slideshow','スライドショー','複数の画像をスライドショーとして表示します。',1,0,0,0,550,400,0)
 ,(12,'search','検索','検索ブロックを追加します。「管理画面」ー「メンテナンス」で検索用索引を作成する必要があります。',1,0,0,0,400,170,0)
 ,(13,'google_map','Googleマップ','Google Mapに準拠した住所を入力すると地図が表示されます。',1,0,0,0,400,220,0)
 ,(14,'video','ビデオプレイヤー','ムービーファイルを表示します（AVI、WMV、QuickTime/MPEG4、FLV形式に対応）',1,0,0,0,300,200,0)
 ,(15,'rss_displayer','RSSブロック','RSSやATOMフィードを取得し表示します。',1,0,0,0,400,170,0)
 ,(16,'youtube','YouTubeビデオ','YouTubeビデオを埋め込みます。',1,0,0,0,400,170,0)
 ,(17,'survey','アンケート','シンプルなアンケート。結果を円グラフで表示します。',1,0,1,0,420,300,0)
 ,(18,'date_nav','日付ナビ','伸縮する日付ナビ',1,0,0,0,500,350,0)
 ,(19,'next_previous','「次へ」「前へ」ナビ','同じ階層ページへのリンク',1,0,0,0,430,300,0)
 ,(20,'tags','Tags','タグクラウドを表示します。',1,0,0,0,500,350,0);

INSERT INTO Blocks VALUES(1,NULL,NOW(),NOW(),'header_menu.php','1',3,1)
 ,(2,NULL,NOW(),NOW(),NULL,'1',11,1)
 ,(3,NULL,NOW(),NOW(),NULL,'1',3,1)
 ,(4,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(5,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(6,NULL,NOW(),NOW(),NULL,'1',16,1)
 ,(7,NULL,NOW(),NOW(),'header_menu.php','1',3,1)
 ,(8,NULL,NOW(),NOW(),NULL,'1',8,1)
 ,(9,NULL,NOW(),NOW(),NULL,'1',3,1)
 ,(10,NULL,NOW(),NOW(),'header_menu.php','1',3,1)
 ,(11,NULL,NOW(),NOW(),NULL,'1',8,1)
 ,(12,NULL,NOW(),NOW(),'header_menu.php','1',3,1)
 ,(13,NULL,NOW(),NOW(),NULL,'1',8,1)
 ,(14,NULL,NOW(),NOW(),'breadcrumb.php','1',3,1)
 ,(15,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(16,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(17,NULL,NOW(),NOW(),NULL,'1',10,1)
 ,(18,NULL,NOW(),NOW(),NULL,'1',18,1)
 ,(19,NULL,NOW(),NOW(),NULL,'1',12,1)
 ,(20,NULL,NOW(),NOW(),NULL,'1',3,1)
 ,(21,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(22,NULL,NOW(),NOW(),NULL,'1',12,1)
 ,(23,NULL,NOW(),NOW(),NULL,'1',20,1)
 ,(24,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(25,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(26,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(27,NULL,NOW(),NOW(),NULL,'1',10,1)
 ,(28,NULL,NOW(),NOW(),NULL,'1',18,1)
 ,(29,NULL,NOW(),NOW(),'tag_cloud','1',12,1)
 ,(30,NULL,NOW(),NOW(),'blog_index.php','1',6,1)
 ,(31,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(32,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(33,NULL,NOW(),NOW(),NULL,'1',20,1)
 ,(34,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(35,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(36,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(37,NULL,NOW(),NOW(),NULL,'1',17,1)
 ,(38,NULL,NOW(),NOW(),NULL,'1',1,1)
 ,(39,NULL,NOW(),NOW(),NULL,'1',20,1)
 ,(40,NULL,NOW(),NOW(),NULL,'1',19,1)
 ,(41,'My_Site_Name',NOW(),NOW(),NULL,'1',1,1);

INSERT INTO CollectionAttributeValues VALUES(66,1,11,19)
 ,(67,2,1,11)
 ,(67,2,2,12)
 ,(67,2,3,13)
 ,(67,2,4,14)
 ,(67,3,1,11)
 ,(67,3,2,12)
 ,(67,3,3,13)
 ,(67,3,4,14)
 ,(68,2,1,15)
 ,(68,2,2,16)
 ,(68,2,3,17)
 ,(68,2,4,18)
 ,(69,2,1,20)
 ,(69,2,2,21)
 ,(69,2,3,22)
 ,(69,2,4,23)
 ,(69,3,1,20)
 ,(69,3,2,21)
 ,(69,3,3,22)
 ,(69,3,4,23)
 ,(70,2,1,24)
 ,(70,2,2,25)
 ,(70,2,3,26)
 ,(70,2,4,27)
 ,(70,3,1,28)
 ,(70,3,2,29)
 ,(70,3,3,30)
 ,(70,3,4,31)
 ,(71,2,1,32)
 ,(71,2,2,33)
 ,(71,2,3,34)
 ,(71,2,4,35)
 ,(72,2,1,36)
 ,(72,2,2,37)
 ,(72,2,3,38)
 ,(72,2,4,39)
 ,(72,2,11,40)
 ,(72,3,1,36)
 ,(72,3,2,37)
 ,(72,3,3,38)
 ,(72,3,4,39)
 ,(72,3,11,40)
 ,(72,4,1,36)
 ,(72,4,2,37)
 ,(72,4,3,38)
 ,(72,4,4,39)
 ,(72,4,11,40)
 ,(73,2,1,41)
 ,(73,2,2,42)
 ,(73,2,3,43)
 ,(73,2,4,44)
 ,(73,3,1,41)
 ,(73,3,2,42)
 ,(73,3,3,43)
 ,(73,3,4,44)
 ,(73,3,11,45)
 ,(73,4,1,41)
 ,(73,4,2,42)
 ,(73,4,3,43)
 ,(73,4,4,44)
 ,(73,4,11,45);

INSERT INTO CollectionVersionBlockStyles VALUES(1,2,1,'Header Nav',0)
 ,(1,2,2,'Header',0)
 ,(1,3,1,'Header Nav',0)
 ,(1,3,2,'Header',0)
 ,(67,1,7,'Header Nav',0)
 ,(67,1,8,'Header',0)
 ,(67,1,9,'Sidebar',0)
 ,(67,2,7,'Header Nav',0)
 ,(67,2,8,'Header',0)
 ,(67,2,9,'Sidebar',0)
 ,(68,1,7,'Header Nav',0)
 ,(68,1,8,'Header',0)
 ,(68,1,9,'Sidebar',0)
 ,(68,2,7,'Header Nav',0)
 ,(68,2,8,'Header',0)
 ,(68,2,9,'Sidebar',0)
 ,(69,1,8,'Header',0)
 ,(69,1,7,'Header Nav',0)
 ,(69,1,9,'Sidebar',0)
 ,(69,2,7,'Header Nav',0)
 ,(69,2,8,'Header',0)
 ,(69,2,9,'Sidebar',0)
 ,(69,3,7,'Header Nav',0)
 ,(69,3,8,'Header',0)
 ,(69,3,9,'Sidebar',0)
 ,(69,3,24,'Main',0)
 ,(70,1,7,'Header Nav',0)
 ,(70,1,8,'Header',0)
 ,(70,1,9,'Sidebar',0)
 ,(70,2,7,'Header Nav',0)
 ,(70,2,8,'Header',0)
 ,(70,2,9,'Sidebar',0)
 ,(70,3,7,'Header Nav',0)
 ,(70,3,8,'Header',0)
 ,(70,3,9,'Sidebar',0)
 ,(70,3,26,'Main',0)
 ,(71,1,1,'Header Nav',0)
 ,(71,1,2,'Header',0)
 ,(71,1,3,'Sidebar',0)
 ,(71,2,1,'Header Nav',0)
 ,(71,2,2,'Header',0)
 ,(72,1,12,'Header Nav',0)
 ,(72,1,13,'Header',0)
 ,(72,1,14,'Blog Post Header',0)
 ,(72,1,15,'Main',0)
 ,(72,1,16,'Blog Post More',0)
 ,(72,1,17,'Blog Post Footer',0)
 ,(72,1,18,'Sidebar',0)
 ,(72,1,23,'Sidebar',0)
 ,(72,2,12,'Header Nav',0)
 ,(72,2,13,'Header',0)
 ,(72,2,14,'Blog Post Header',0)
 ,(72,2,32,'Blog Post More',0)
 ,(72,2,33,'Sidebar',0)
 ,(72,2,17,'Blog Post Footer',0)
 ,(72,2,18,'Sidebar',0)
 ,(72,3,12,'Header Nav',0)
 ,(72,2,31,'Main',0)
 ,(72,3,13,'Header',0)
 ,(72,3,14,'Blog Post Header',0)
 ,(72,3,17,'Blog Post Footer',0)
 ,(72,3,18,'Sidebar',0)
 ,(72,3,35,'Blog Post More',0)
 ,(73,1,12,'Header Nav',0)
 ,(72,3,33,'Sidebar',0)
 ,(72,3,34,'Main',0)
 ,(73,1,13,'Header',0)
 ,(73,1,14,'Blog Post Header',0)
 ,(73,1,15,'Main',0)
 ,(73,1,16,'Blog Post More',0)
 ,(73,1,17,'Blog Post Footer',0)
 ,(73,1,18,'Sidebar',0)
 ,(73,1,23,'Sidebar',0)
 ,(73,2,12,'Header Nav',0)
 ,(73,2,13,'Header',0)
 ,(73,2,14,'Blog Post Header',0)
 ,(73,3,13,'Header',0)
 ,(73,3,12,'Header Nav',0)
 ,(73,2,17,'Blog Post Footer',0)
 ,(73,2,18,'Sidebar',0)
 ,(73,2,23,'Sidebar',0)
 ,(73,2,36,'Main',0)
 ,(73,3,14,'Blog Post Header',0)
 ,(73,3,17,'Blog Post Footer',0)
 ,(73,3,18,'Sidebar',0)
 ,(73,3,36,'Main',0)
 ,(73,3,38,'Blog Post More',0)
 ,(73,3,39,'Sidebar',0)
 ,(73,3,40,'Blog Post Footer',0)
 ,(72,3,40,'Blog Post Footer',0);

INSERT INTO CollectionVersionBlocks VALUES(2,1,1,'Header Nav',0,'1',0,0)
 ,(2,1,2,'Header',0,'1',0,0)
 ,(2,1,3,'Sidebar',0,'1',0,0)
 ,(1,2,1,'Header Nav',0,'0',0,0)
 ,(1,2,2,'Header',0,'0',0,0)
 ,(1,3,1,'Header Nav',0,'0',0,0)
 ,(1,3,2,'Header',0,'0',0,0)
 ,(1,3,4,'Sidebar',0,'1',0,0)
 ,(1,3,5,'Main',0,'1',0,0)
 ,(1,3,6,'Main',1,'1',0,0)
 ,(64,1,7,'Header Nav',0,'1',0,0)
 ,(64,1,8,'Header',0,'1',0,0)
 ,(64,1,9,'Sidebar',0,'1',0,0)
 ,(65,1,10,'Header Nav',0,'1',0,0)
 ,(65,1,11,'Header',0,'1',0,0)
 ,(66,1,12,'Header Nav',0,'1',0,0)
 ,(66,1,13,'Header',0,'1',0,0)
 ,(66,1,14,'Blog Post Header',0,'1',0,0)
 ,(66,1,15,'Main',0,'1',0,0)
 ,(66,1,16,'Blog Post More',0,'1',0,0)
 ,(66,1,17,'Blog Post Footer',1,'1',0,1)
 ,(66,1,18,'Sidebar',0,'1',0,0)
 ,(67,1,7,'Header Nav',0,'0',0,0)
 ,(67,1,8,'Header',0,'0',0,0)
 ,(67,1,9,'Sidebar',0,'0',0,0)
 ,(67,2,7,'Header Nav',0,'0',0,0)
 ,(67,2,8,'Header',0,'0',0,0)
 ,(67,2,9,'Sidebar',0,'0',0,0)
 ,(68,1,7,'Header Nav',0,'0',0,0)
 ,(68,1,8,'Header',0,'0',0,0)
 ,(68,1,9,'Sidebar',0,'0',0,0)
 ,(68,2,7,'Header Nav',0,'0',0,0)
 ,(68,2,8,'Header',0,'0',0,0)
 ,(68,2,9,'Sidebar',0,'0',0,0)
 ,(68,2,19,'Main',0,'1',0,0)
 ,(67,3,7,'Header Nav',0,'0',0,0)
 ,(67,3,8,'Header',0,'0',0,0)
 ,(67,3,22,'Sidebar',0,'1',0,0)
 ,(67,3,20,'Main',1,'1',0,0)
 ,(67,3,21,'Main',0,'1',0,0)
 ,(66,1,23,'Sidebar',1,'1',0,0)
 ,(69,1,7,'Header Nav',0,'0',0,0)
 ,(69,1,8,'Header',0,'0',0,0)
 ,(69,1,9,'Sidebar',0,'0',0,0)
 ,(69,2,7,'Header Nav',0,'0',0,0)
 ,(69,2,8,'Header',0,'0',0,0)
 ,(69,2,9,'Sidebar',0,'0',0,0)
 ,(69,2,24,'Main',0,'1',0,0)
 ,(69,3,7,'Header Nav',0,'0',0,0)
 ,(69,3,8,'Header',0,'0',0,0)
 ,(69,3,9,'Sidebar',0,'0',0,0)
 ,(69,3,24,'Main',0,'0',0,0)
 ,(69,3,25,'Main',1,'1',0,0)
 ,(70,1,7,'Header Nav',0,'0',0,0)
 ,(70,1,8,'Header',0,'0',0,0)
 ,(70,1,9,'Sidebar',0,'0',0,0)
 ,(70,2,7,'Header Nav',0,'0',0,0)
 ,(70,2,8,'Header',0,'0',0,0)
 ,(70,2,9,'Sidebar',0,'0',0,0)
 ,(70,2,26,'Main',0,'1',0,0)
 ,(70,2,27,'Main',1,'1',0,1)
 ,(70,3,7,'Header Nav',0,'0',0,0)
 ,(70,3,8,'Header',0,'0',0,0)
 ,(70,3,9,'Sidebar',0,'0',0,0)
 ,(70,3,26,'Main',0,'0',0,0)
 ,(71,1,1,'Header Nav',0,'0',0,0)
 ,(71,1,2,'Header',0,'0',0,0)
 ,(71,1,3,'Sidebar',0,'0',0,0)
 ,(71,2,1,'Header Nav',0,'0',0,0)
 ,(71,2,2,'Header',0,'0',0,0)
 ,(71,2,28,'Sidebar',0,'1',0,0)
 ,(71,2,29,'Sidebar',1,'1',0,0)
 ,(71,2,30,'Main',0,'1',0,0)
 ,(72,1,12,'Header Nav',0,'0',0,0)
 ,(72,1,13,'Header',0,'0',0,0)
 ,(72,1,14,'Blog Post Header',0,'0',0,0)
 ,(72,1,15,'Main',0,'0',0,0)
 ,(72,1,16,'Blog Post More',0,'0',0,0)
 ,(72,1,17,'Blog Post Footer',0,'0',0,0)
 ,(72,1,18,'Sidebar',0,'0',0,0)
 ,(72,1,23,'Sidebar',1,'0',0,0)
 ,(72,2,12,'Header Nav',0,'0',0,0)
 ,(72,2,13,'Header',0,'0',0,0)
 ,(72,2,14,'Blog Post Header',0,'0',0,0)
 ,(72,2,32,'Blog Post More',0,'1',0,0)
 ,(72,2,33,'Sidebar',1,'1',0,0)
 ,(72,2,17,'Blog Post Footer',0,'0',0,0)
 ,(72,2,18,'Sidebar',0,'0',0,0)
 ,(72,3,12,'Header Nav',0,'0',0,0)
 ,(72,2,31,'Main',0,'1',0,0)
 ,(72,3,13,'Header',0,'0',0,0)
 ,(72,3,14,'Blog Post Header',0,'0',0,0)
 ,(72,3,17,'Blog Post Footer',0,'0',0,0)
 ,(72,3,18,'Sidebar',0,'0',0,0)
 ,(72,3,35,'Blog Post More',0,'1',0,0)
 ,(73,1,12,'Header Nav',0,'0',0,0)
 ,(72,3,33,'Sidebar',1,'0',0,0)
 ,(72,3,34,'Main',0,'1',0,0)
 ,(73,1,13,'Header',0,'0',0,0)
 ,(73,1,14,'Blog Post Header',0,'0',0,0)
 ,(73,1,15,'Main',0,'0',0,0)
 ,(73,1,16,'Blog Post More',0,'0',0,0)
 ,(73,1,17,'Blog Post Footer',0,'0',0,0)
 ,(73,1,18,'Sidebar',0,'0',0,0)
 ,(73,1,23,'Sidebar',1,'0',0,0)
 ,(73,2,12,'Header Nav',0,'0',0,0)
 ,(73,2,13,'Header',0,'0',0,0)
 ,(73,2,14,'Blog Post Header',0,'0',0,0)
 ,(73,2,38,'Blog Post More',0,'1',0,0)
 ,(73,2,37,'Main',1,'1',0,1)
 ,(73,2,17,'Blog Post Footer',0,'0',0,0)
 ,(73,2,18,'Sidebar',0,'0',0,0)
 ,(73,2,23,'Sidebar',1,'0',0,0)
 ,(73,2,36,'Main',0,'1',0,0)
 ,(73,3,12,'Header Nav',0,'0',0,0)
 ,(73,3,13,'Header',0,'0',0,0)
 ,(73,3,14,'Blog Post Header',0,'0',0,0)
 ,(73,3,17,'Blog Post Footer',0,'0',0,0)
 ,(73,3,18,'Sidebar',0,'0',0,0)
 ,(73,3,36,'Main',0,'0',0,0)
 ,(73,3,38,'Blog Post More',0,'0',0,0)
 ,(73,3,39,'Sidebar',1,'1',0,0)
 ,(66,1,40,'Blog Post Footer',0,'1',0,0)
 ,(73,3,40,'Blog Post Footer',1,'0',0,0)
 ,(72,3,40,'Blog Post Footer',1,'0',0,0)
 ,(72,4,12,'Header Nav',0,'0',0,0)
 ,(72,4,13,'Header',0,'0',0,0)
 ,(72,4,14,'Blog Post Header',0,'0',0,0)
 ,(72,4,17,'Blog Post Footer',1,'0',0,0)
 ,(72,4,18,'Sidebar',0,'0',0,0)
 ,(72,4,34,'Main',0,'0',0,0)
 ,(72,4,35,'Blog Post More',0,'0',0,0)
 ,(72,4,33,'Sidebar',1,'0',0,0)
 ,(72,4,40,'Blog Post Footer',0,'0',0,0)
 ,(73,4,12,'Header Nav',0,'0',0,0)
 ,(73,4,13,'Header',0,'0',0,0)
 ,(73,4,14,'Blog Post Header',0,'0',0,0)
 ,(73,4,17,'Blog Post Footer',1,'0',0,0)
 ,(73,4,18,'Sidebar',0,'0',0,0)
 ,(73,4,36,'Main',0,'0',0,0)
 ,(73,4,38,'Blog Post More',0,'0',0,0)
 ,(73,4,39,'Sidebar',1,'0',0,0)
 ,(73,4,40,'Blog Post Footer',0,'0',0,0)
 ,(36,2,41,'Global',0,'1',0,0);

INSERT INTO CollectionVersions VALUES(2,1,NULL,NULL,NULL,NOW(),NOW(),'初稿',1,0,1,1,NULL)
 ,(1,2,'ホーム','home',NULL,NOW(),NOW(),'新しいバージョン 2',0,0,1,1,NULL)
 ,(5,1,'ログイン','login',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(6,1,'登録','register',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(7,1,'プロフィール','profile',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(8,1,'編集','edit',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(10,1,'プロフィール画像','avatar',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(11,1,'メッセージ','messages',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(12,1,'マイフレンド','friends',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(13,1,'Page Not Found（ページが見つかりません）','page_not_found',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(14,1,'Page Forbidden（アクセス禁止）','page_forbidden',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(15,1,'管理画面','dashboard',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(16,1,'サイトマップ','sitemap','サイトの全体図',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(17,1,'全サイトマップ','full',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(18,1,'フラットビュー','explore',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(19,1,'ページ検索','search',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(20,1,'アクセス権限','access',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(21,1,'ファイルマネージャー','files','画像などのファイルを管理',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(22,1,'検索','search',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(23,1,'属性管理','attributes',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(24,1,'セット','sets',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(25,1,'アクセス権限','access',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(26,1,'レポート','reports','フォームやログの情報を閲覧',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(27,1,'フォーム一覧','forms','Get submission data.',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(28,1,'アンケート','surveys',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(29,1,'ログ','logs',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(30,1,'ユーザー・グループ管理','users','ユーザー追加と管理',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(31,1,'ユーザー検索・一覧','search',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(32,1,'ユーザー追加','add',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(33,1,'グループ','groups',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(34,1,'ユーザー項目','attributes',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(35,1,'ログイン & ユーザー登録','registration',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(36,1,'下書き','scrapbook','ブロックをサイト全体で使い回す',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(37,1,'ページとテーマ','pages','デザイン管理',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(38,1,'テーマ','themes','デザインを管理',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(39,1,'テーマ追加','add',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(40,1,'テーマ検査','inspect',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(41,1,'テーマをカスタマイズ','customize',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(43,1,'ページタイプ','types','デザイン管理',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(44,1,'属性情報','attributes',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(45,1,'シングルページ','single',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(46,1,'機能を追加','install','アドオンやテーマを追加',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(47,1,'システム & メンテナンス','system','バックアップ、復元、アップデート',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(48,1,'ジョブ','jobs',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(49,1,'DBバックアップ & 復元','backup',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(50,1,'更新','update',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(51,1,'お知らせ','notifications',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(52,1,'サイト全体の設定','settings','外部メールからの投稿やその他の設定',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(53,1,'Email','mail','Enable post via email and other settings.',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(54,1,'マーケットプレイス','marketplace',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(55,1,'ファイルダウンロード','download_file',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(63,1,NULL,'uID=1',NULL,NOW(),NOW(),'初稿',1,0,NULL,NULL,NULL)
 ,(1,3,'ホーム','home',NULL,NOW(),NOW(),'新しいバージョン 3',1,0,1,1,NULL)
 ,(64,1,'',NULL,NULL,NOW(),NOW(),'初稿',1,0,NULL,NULL,NULL)
 ,(65,1,'',NULL,NULL,NOW(),NOW(),'初稿',1,0,NULL,1,NULL)
 ,(66,1,'',NULL,NULL,NOW(),NOW(),'初稿',1,0,NULL,1,NULL)
 ,(67,1,'検索','search','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(67,2,'検索','search','',NOW(),NOW(),'新しいバージョン 2',0,0,1,1,NULL)
 ,(68,1,'検索結果','search-results','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(68,2,'検索結果','search-results','',NOW(),NOW(),'新しいバージョン 2',1,0,1,1,NULL)
 ,(67,3,'検索','search','',NOW(),NOW(),'新しいバージョン 3',1,0,1,1,NULL)
 ,(69,1,'About','about','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(69,2,'About','about','',NOW(),NOW(),'New Version 2',0,0,1,1,NULL)
 ,(69,3,'About','about','',NOW(),NOW(),'New Version 3',1,0,1,1,NULL)
 ,(70,1,'ゲストブック','guest-book','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(70,2,'ゲストブック','guest-book','',NOW(),NOW(),'新しいバージョン 2',0,0,1,1,NULL)
 ,(70,3,'ゲストブック','guest-book','',NOW(),NOW(),'新しいバージョン 3',1,0,1,1,NULL)
 ,(71,1,'ブログ','blog','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(71,2,'ブログ','blog','',NOW(),NOW(),'Version 2',1,0,1,1,NULL)
 ,(72,1,'最初のブログ投稿','my-first-blog-post','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(72,2,'最初のブログ投稿','my-first-blog-post','',NOW(),NOW(),'新しいバージョン 2',0,0,1,1,NULL)
 ,(72,3,'最初のブログ投稿','my-first-blog-post','',NOW(),NOW(),'新しいバージョン 3',0,0,1,1,NULL)
 ,(73,1,'新しい投稿を追加','adding-a-new-post','',NOW(),NOW(),'初稿',0,0,1,NULL,NULL)
 ,(73,2,'新しい投稿を追加','adding-a-new-post','',NOW(),NOW(),'新しいバージョン 2',0,0,1,1,NULL)
 ,(73,3,'新しい投稿を追加','adding-a-new-post','',NOW(),NOW(),'新しいバージョン 3',0,0,1,1,NULL)
 ,(74,1,'メンバー','members',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(72,4,'最初のブログ投稿','my-first-blog-post','',NOW(),NOW(),'新しいバージョン 4',1,0,1,1,NULL)
 ,(73,4,'新しい投稿を追加','adding-a-new-post','',NOW(),NOW(),'新しいバージョン 4',1,0,1,1,NULL)
 ,(36,2,'下書き','scrapbook','ブロックをサイト全体で使い回す',NOW(),NOW(),'新しいバージョン 2',0,1,1,NULL,NULL)
 ,(75,1,'コンポーザーベータ','composer','Write for your site.',NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(76,1,'新規','write',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(77,1,'草稿','drafts',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(78,1,'コンポーザー','composer',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL)
 ,(79,1,'多言語設定','multilingual',NULL,NOW(),NOW(),'初稿',1,0,1,NULL,NULL);

INSERT INTO Collections VALUES(1,NOW(),NOW(),'home')
 ,(2,NOW(),NOW(),NULL)
 ,(5,NOW(),NOW(),'login')
 ,(6,NOW(),NOW(),'register')
 ,(7,NOW(),NOW(),'profile')
 ,(8,NOW(),NOW(),'edit')
 ,(10,NOW(),NOW(),'avatar')
 ,(11,NOW(),NOW(),'messages')
 ,(12,NOW(),NOW(),'friends')
 ,(13,NOW(),NOW(),'page_not_found')
 ,(14,NOW(),NOW(),'page_forbidden')
 ,(15,NOW(),NOW(),'dashboard')
 ,(16,NOW(),NOW(),'sitemap')
 ,(17,NOW(),NOW(),'full')
 ,(18,NOW(),NOW(),'explore')
 ,(19,NOW(),NOW(),'search')
 ,(20,NOW(),NOW(),'access')
 ,(21,NOW(),NOW(),'files')
 ,(22,NOW(),NOW(),'search')
 ,(23,NOW(),NOW(),'attributes')
 ,(24,NOW(),NOW(),'sets')
 ,(25,NOW(),NOW(),'access')
 ,(26,NOW(),NOW(),'reports')
 ,(27,NOW(),NOW(),'forms')
 ,(28,NOW(),NOW(),'surveys')
 ,(29,NOW(),NOW(),'logs')
 ,(30,NOW(),NOW(),'users')
 ,(31,NOW(),NOW(),'search')
 ,(32,NOW(),NOW(),'add')
 ,(33,NOW(),NOW(),'groups')
 ,(34,NOW(),NOW(),'attributes')
 ,(35,NOW(),NOW(),'registration')
 ,(36,NOW(),NOW(),'scrapbook')
 ,(37,NOW(),NOW(),'pages')
 ,(38,NOW(),NOW(),'themes')
 ,(39,NOW(),NOW(),'add')
 ,(40,NOW(),NOW(),'inspect')
 ,(41,NOW(),NOW(),'customize')
 ,(43,NOW(),NOW(),'types')
 ,(44,NOW(),NOW(),'attributes')
 ,(45,NOW(),NOW(),'single')
 ,(46,NOW(),NOW(),'install')
 ,(47,NOW(),NOW(),'system')
 ,(48,NOW(),NOW(),'jobs')
 ,(49,NOW(),NOW(),'backup')
 ,(50,NOW(),NOW(),'update')
 ,(51,NOW(),NOW(),'notifications')
 ,(52,NOW(),NOW(),'settings')
 ,(53,NOW(),NOW(),'mail')
 ,(54,NOW(),NOW(),'marketplace')
 ,(55,NOW(),NOW(),'download_file')
 ,(63,NOW(),NOW(),'uID=1')
 ,(64,NOW(),NOW(),NULL)
 ,(65,NOW(),NOW(),NULL)
 ,(66,NOW(),NOW(),NULL)
 ,(67,NOW(),NOW(),'search')
 ,(68,NOW(),NOW(),'search-results')
 ,(69,NOW(),NOW(),'about')
 ,(70,NOW(),NOW(),'guest-book')
 ,(71,NOW(),NOW(),'blog')
 ,(72,NOW(),NOW(),'my-first-blog-post')
 ,(73,NOW(),NOW(),'adding-a-new-post')
 ,(74,NOW(),NOW(),'members')
 ,(75,NOW(),NOW(),'composer')
 ,(76,NOW(),NOW(),'write')
 ,(77,NOW(),NOW(),'drafts')
 ,(78,NOW(),NOW(),'composer')
 ,(79,NOW(),NOW(),'multilingual');

INSERT INTO DashboardHomepage VALUES(1,'activity','サイトアクティビティー',0,0)
 ,(2,'reports','アクセス解析',0,0)
 ,(3,'help','ヘルプ',0,0)
 ,(4,'news','最新情報',0,0)
 ,(5,'notes','管理ノート',0,0);

INSERT INTO FileAttributeValues VALUES(1,1,9,1)
 ,(1,1,10,2)
 ,(2,1,9,3)
 ,(2,1,10,4)
 ,(3,1,9,5)
 ,(3,1,10,6)
 ,(4,1,9,7)
 ,(4,1,10,8)
 ,(5,1,9,9)
 ,(5,1,10,10);

INSERT INTO FileSetPermissions VALUES(0,1,0,10,0,0,0,0)
 ,(0,2,0,10,0,0,0,0)
 ,(0,3,0,10,10,10,10,10);

INSERT INTO FileVersionLog VALUES(1,1,1,5,9)
 ,(2,1,1,5,10)
 ,(3,2,1,5,9)
 ,(4,2,1,5,10)
 ,(5,3,1,5,9)
 ,(6,3,1,5,10)
 ,(7,4,1,5,9)
 ,(8,4,1,5,10)
 ,(9,5,1,5,9)
 ,(10,5,1,5,10)
 ,(11,1,1,3,0)
 ,(12,1,1,4,0)
 ,(13,2,1,3,0)
 ,(14,2,1,4,0)
 ,(15,3,1,3,0)
 ,(16,3,1,4,0)
 ,(17,4,1,3,0)
 ,(18,4,1,4,0)
 ,(19,5,1,3,0)
 ,(20,5,1,4,0);

INSERT INTO FileVersions VALUES(1,1,'inneroptics_dot_net_aspens.jpg','371285369023',1,108199,'inneroptics_dot_net_aspens.jpg','','',1,NOW(),1,1,NOW(),1,1,0,'jpg',1)
 ,(2,1,'inneroptics_dot_net_canyonlands.jpg','911285369025',1,54531,'inneroptics_dot_net_canyonlands.jpg','','',1,NOW(),1,1,NOW(),1,1,0,'jpg',1)
 ,(3,1,'inneroptics_dot_net_new_zealand_sheep.jpg','851285369025',1,80735,'inneroptics_dot_net_new_zealand_sheep.jpg','','',1,NOW(),1,1,NOW(),1,1,0,'jpg',1)
 ,(4,1,'inneroptics_dot_net_portland.jpg','711285369026',1,55737,'inneroptics_dot_net_portland.jpg','','',1,NOW(),1,1,NOW(),1,1,0,'jpg',1)
 ,(5,1,'inneroptics_dot_net_starfish.jpg','701285369026',1,88621,'inneroptics_dot_net_starfish.jpg','','',1,NOW(),1,1,NOW(),1,1,0,'jpg',1);

INSERT INTO Files VALUES(1,NOW(),1,0,2,0,NULL)
 ,(2,NOW(),1,0,2,0,NULL)
 ,(3,NOW(),1,0,2,0,NULL)
 ,(4,NOW(),1,0,2,0,NULL)
 ,(5,NOW(),1,0,2,0,NULL);

INSERT INTO Groups VALUES(1,'ゲスト','ゲストグループとは、ログインしていないサイト訪問者を指します',0,NULL,NULL,0,NULL)
 ,(2,'登録ユーザー','登録ユーザーとは、ログインしているユーザー全員を指します',0,NULL,NULL,0,NULL)
 ,(3,'管理者','',0,NULL,NULL,0,NULL);

INSERT INTO Jobs VALUES(1,'検索用索引の作成','検索ブロックを使用する際、検索用索引を作成する必要があります。',NOW(),NOW(),0,'索引が更新されました。6ページがインデックス（索引）されました。',0,'ENABLED','index_search',1)
 ,(2,'サイトマップファイルを作成','sitemap.xmlをルートフォルダーに生成します。これを検索サイトに巡回させる事により、検索サイトへの登録がスムーズになる可能性があります。',NOW(),NOW(),0,'サイトマップXMLファイルが保存されました。',0,'ENABLED','generate_sitemap',0)
 ,(3,'メール投稿を処理','メールサーバーにアクセスし、サイト向けメッセージや投稿を取り込みます。',NOW(),NOW(),0,'この処理は成功しました。',0,'ENABLED','process_email',0);

INSERT INTO MailImporters VALUES(1,'private_message',NULL,NULL,NULL,NULL,0,NULL,0,0);

INSERT INTO PagePaths VALUES(1,5,'/login','1')
 ,(2,6,'/register','1')
 ,(3,7,'/profile','1')
 ,(4,8,'/profile/edit','1')
 ,(6,10,'/profile/avatar','1')
 ,(7,11,'/profile/messages','1')
 ,(8,12,'/profile/friends','1')
 ,(9,13,'/page_not_found','1')
 ,(10,14,'/page_forbidden','1')
 ,(11,15,'/dashboard','1')
 ,(12,16,'/dashboard/sitemap','1')
 ,(13,17,'/dashboard/sitemap/full','1')
 ,(14,18,'/dashboard/sitemap/explore','1')
 ,(15,19,'/dashboard/sitemap/search','1')
 ,(16,20,'/dashboard/sitemap/access','1')
 ,(17,21,'/dashboard/files','1')
 ,(18,22,'/dashboard/files/search','1')
 ,(19,23,'/dashboard/files/attributes','1')
 ,(20,24,'/dashboard/files/sets','1')
 ,(21,25,'/dashboard/files/access','1')
 ,(22,26,'/dashboard/reports','1')
 ,(23,27,'/dashboard/reports/forms','1')
 ,(24,28,'/dashboard/reports/surveys','1')
 ,(25,29,'/dashboard/reports/logs','1')
 ,(26,30,'/dashboard/users','1')
 ,(27,31,'/dashboard/users/search','1')
 ,(28,32,'/dashboard/users/add','1')
 ,(29,33,'/dashboard/users/groups','1')
 ,(30,34,'/dashboard/users/attributes','1')
 ,(31,35,'/dashboard/users/registration','1')
 ,(32,36,'/dashboard/scrapbook','1')
 ,(33,37,'/dashboard/pages','1')
 ,(34,38,'/dashboard/pages/themes','1')
 ,(35,39,'/dashboard/pages/themes/add','1')
 ,(36,40,'/dashboard/pages/themes/inspect','1')
 ,(37,41,'/dashboard/pages/themes/customize','1')
 ,(39,43,'/dashboard/pages/types','1')
 ,(40,44,'/dashboard/pages/attributes','1')
 ,(41,45,'/dashboard/pages/single','1')
 ,(42,46,'/dashboard/install','1')
 ,(43,47,'/dashboard/system','1')
 ,(44,48,'/dashboard/system/jobs','1')
 ,(45,49,'/dashboard/system/backup','1')
 ,(46,50,'/dashboard/system/update','1')
 ,(47,51,'/dashboard/system/notifications','1')
 ,(48,52,'/dashboard/settings','1')
 ,(49,53,'/dashboard/settings/mail','1')
 ,(50,54,'/dashboard/settings/marketplace','1')
 ,(51,55,'/download_file','1')
 ,(54,67,'/search','1')
 ,(55,68,'/search/search-results','1')
 ,(57,69,'/about','1')
 ,(59,70,'/about/guest-book','1')
 ,(61,71,'/blog','1')
 ,(67,72,'/blog/my-first-blog-post','1')
 ,(68,73,'/blog/adding-a-new-post','1')
 ,(66,74,'/members','1')
 ,(69,75,'/dashboard/composer','1')
 ,(70,76,'/dashboard/composer/write','1')
 ,(71,77,'/dashboard/composer/drafts','1')
 ,(72,78,'/dashboard/pages/types/composer','1')
 ,(73,79,'/dashboard/settings/multilingual','1');

 
INSERT INTO PagePermissions VALUES(5,1,0,'r',NULL,NULL)
 ,(5,2,0,'r',NULL,NULL)
 ,(6,1,0,'r',NULL,NULL)
 ,(15,3,0,'r:wa:adm',NULL,NULL)
 ,(1,1,0,'r',NULL,NULL)
 ,(1,3,0,'r:rv:wa:db:av:dc:adm',NULL,NULL);


INSERT INTO PageSearchIndex VALUES(1,'オープンソース CMS - concrete5 にようこそ\r\nconcrete5は、WEBサイトを見たまま直接編集ができるコンテンツマネジメントシステムです。ログインするとブロックと呼ばれるページの構成要素を、簡単に変更したり追加できるようになります。 \r\n 以下が簡単な操作方法へのリンクです： \r\n\r\nページの編集方法\r\n新規ページ作成方法\r\nいろいろな機能を持ったブロックを追加：フォーム\r\nテーマやアドオンをマーケットプレイスから簡単自動インストール\r\n\r\n このサイトに、いろいろなサンプルをインストールしました。各ページへは 【管理画面】- 【サイトマップ】よりアクセスできます。いろいろなブロックを各ページで追加したり削除したりしてみてください。 \r\n &nbsp;  サイドバー\r\n concrete5はすべての部分をカスタマイズ出来るCMSです。ここは、サイドバー・エリアで、メインエリアとは違うエリアです。移動モードにしドラックアンドドロップで他のエリアに自由にブロックを動かすことができます。 \r\n &nbsp;  ','ホーム',NULL,NULL,NOW(),'2010-11-26 00:16:08',NULL)
 ,(67,'サイトマップ ','検索','','/search',NOW(),'2010-11-26 00:24:08',NULL)
 ,(68,'','検索結果','','/search/search-results',NOW(),'2010-11-26 00:24:37',NULL)
 ,(66,' Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum vel tellus lectus, scelerisque faucibus nunc. Curabitur lacus nibh, eleifend vel porttitor in, bibendum quis tortor. Curabitur eros ligula, scelerisque ac ultricies a, dictum ac tellus. Mauris id tellus tortor. Proin a sollicitudin libero. Nam pellentesque commodo magna, nec mattis elit pulvinar id. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Mauris orci dui, adipiscing sit amet bibendum vel, sodales sed purus. Donec fringilla odio vel enim cursus luctus quis semper leo. Donec rhoncus odio ac elit dignissim lobortis. \r\n &nbsp;   Duis dapibus nibh eu arcu viverra tempor. Fusce auctor sapien eu mauris malesuada vel euismod orci vulputate. Curabitur at orci id quam mollis rhoncus vitae volutpat urna. Nam eget sapien at neque mollis varius sed vitae ipsum. Vestibulum commodo, eros sit amet sagittis cursus, massa mi lacinia lorem, vel pellentesque sapien purus eu lacus. Pellentesque mollis gravida enim. Fusce mi odio, elementum ut fermentum a, pharetra in quam. Mauris sed vestibulum sapien. In sit amet faucibus diam. Proin lectus quam, sodales ut posuere non, viverra a nibh. Aenean sollicitudin, diam eu elementum rutrum, nisi ante pretium mi, ut tristique ante tellus non ligula. Nam diam turpis, viverra non volutpat vel, scelerisque vel neque. In pretium, libero et vulputate varius, libero nulla blandit ligula, tincidunt egestas leo mi eu nisi. Mauris nunc augue, cursus vel viverra non, feugiat in enim. In eget dignissim est. Donec dictum leo in libero tincidunt sollicitudin hendrerit elit placerat. Aliquam vitae nunc diam, non vulputate nibh. Quisque tincidunt, dui ut rutrum feugiat, libero lorem interdum sapien, eget pharetra mi ligula ut lectus. Pellentesque consequat mollis est viverra malesuada. \r\n Curabitur eget quam vitae tellus blandit congue a sed lectus. Nunc ultrices lacus dignissim felis venenatis varius placerat eros dapibus. Nulla facilisi. Vivamus sodales accumsan convallis. Mauris congue tempus feugiat. Proin elementum fringilla leo, sit amet pretium nisl imperdiet interdum. Suspendisse volutpat cursus eros, nec porta est laoreet at. Sed porttitor suscipit augue, eu molestie justo faucibus et. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Vivamus faucibus mi vel tortor consequat eget rutrum nisl ultrices. Praesent et lacinia augue. Phasellus id est id enim ultricies placerat. Etiam porta enim eu enim convallis sed eleifend metus faucibus. In ac lobortis eros. Pellentesque felis turpis, cursus sed imperdiet non, viverra vel diam. Donec vel orci mi, placerat egestas purus. Vestibulum vel diam id magna suscipit accumsan. Quisque risus felis, sagittis non iaculis id, tempus in arcu. Donec tempus metus neque. Proin malesuada dui a tortor pretium tincidunt quis at ligula. \r\n Nam laoreet faucibus purus ac pretium. Aenean euismod diam adipiscing erat semper quis sodales elit tristique. Vestibulum vel tellus eu lorem porttitor aliquet. Vestibulum bibendum viverra cursus. Aenean sit amet magna odio, convallis imperdiet metus. Duis condimentum posuere vulputate. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Sed vitae elit ut sapien vestibulum tempor sit amet ac tortor. Donec ligula nulla, varius id ornare id, vestibulum non felis. Nullam neque erat, tristique a eleifend pellentesque, eleifend sit amet ipsum. In eget urna nibh. Phasellus scelerisque, magna ac feugiat ultricies, risus dolor volutpat quam, in rutrum nunc ante id sem. Fusce interdum scelerisque fermentum. \r\n &nbsp;  ','',NULL,NULL,NOW(),NOW(),NULL)
 ,(69,'もっと学ぼう！\r\n concrete5 日本語公式サイトには、気軽に質問に答えられるコミュニティーやフォーラム、ヘルプページなどがあります。本家公式のマーケットプレイスでは、拡張アドオンやテーマなどをダウンロードすることが出来ます。  よくある質問\r\n サイトヘッダー部分のサイト名の変更の仕方 \r\n index.php を隠すプリティーURLの使い方 \r\n サイトを引越ししたい方「復元（リストア）と引越の仕方」 \r\n テーマを作ったり、見栄えを変更する方法は「テーマの仕組みとデザインの仕方  ','About','','/about',NOW(),'2010-11-26 00:17:53',NULL)
 ,(70,'コメントをどうぞ\r\n ゲストブックブロックは、どのページにも追加できて簡単なコメントを残すことが出来る基本ブロックです。このページを「編集モード」にし、ゲストブロックを選択、メニューから編集をクリックして、設定できる各種項目を確認してみてください。 \r\n また、マーケットプレイスには、掲示板機能を搭載した「Discussions Forum」もあります。 \r\n &nbsp;  ','ゲストブック','','/about/guest-book',NOW(),'2010-11-26 00:19:02',NULL)
 ,(71,'','Blog','','/about/guest-book/blog',NOW(),NOW(),NULL)
 ,(72,' ここが、ブログのイントロ部分です。もしも内容が短ければ、このエリアに全てを記入するとよいでしょう。この「Main」エリアにあるブロックは「ブログ」ページでも表示されます。   「もっと読む」リンクをクリックすると、その記事のページにジャンプします。より詳しい情報を「Blog Post More」エリアにブロックを配置するとここで表示されます。この「Blog Post More」エリア部分は「ブログ」ページ（記事の一覧ページ）には表示されません。 \r\n 「Main」エリアはイントロ部分だけを書いて、ここに詳細の情報等を書いたブロックを設置することにより、ユーザーがもっと読む」リンクをクリックすると、このエリアに掲載されたブロックを表示されるページにジャンプします。  ','最初のブログ投稿','','/blog/my-first-blog-post',NOW(),'2010-11-26 00:21:35',NULL)
 ,(73,' WEBページを見ながら直接編集するのはいいですよね。   concrete5 日本語サイトのヘルプをある程度ご覧になれましたでしょうか？ \r\n ある程度 concrete5 でのサイト運用に慣れたかと思います。新しいブログページを作る方法です。 \r\n\r\nブログページを訪れます。ここが、各ブログ投稿ページの親ページです\r\nログインした状態で、画面左上の「新規ページ」ボタンを押します\r\n「ブログ記事」ページタイプを選択\r\nページ名を入力し改行キー。もしくは、スクロールして「新規」ボタンをクリック。その他の項目は空白で構いません。後で編集モード時、ページ上部の「設定」ボタンより変更できます。\r\nすると、新しいブログ記事ページが出来上がります。ブロックを配置してページを完成させましょう\r\n「編集モード終了」ボタンを押し、ページを公開して、完成です。\r\n ','新しい投稿を追加','','/blog/adding-a-new-post',NOW(),'2010-11-26 00:23:08',NULL)
 ,(74,'','メンバー',NULL,'/members',NOW(),'2010-11-26 00:18:03',NULL);

INSERT INTO PageThemes VALUES(1,'default','プレーンヨーグルト\n','concrete5 デフォルトテーマ',0)
 ,(2,'greensalad','グリーンサラダ\n','緑を基調としたconcrete5 デフォルトテーマ',0)
 ,(3,'dark_chocolate','ダークチョコレート\n','concrete5デフォルトの黒を基調としたテーマ￥',0);

INSERT INTO PageTypeAttributes VALUES(1,1)
 ,(1,2)
 ,(1,3)
 ,(1,4)
 ,(2,1)
 ,(2,2)
 ,(2,3)
 ,(2,4)
 ,(3,1)
 ,(3,2)
 ,(3,3)
 ,(3,4)
 ,(4,1)
 ,(4,2)
 ,(4,3)
 ,(4,4);

INSERT INTO PageTypes VALUES(1,'right_sidebar','template3.png','右サイドバー',0)
 ,(2,'left_sidebar','template1.png','左サイドバー',0)
 ,(3,'full','main.png','全幅',0)
 ,(4,'blog_entry','template2.png','ブログ記事',0);

INSERT INTO Pages VALUES(1,1,'0',1,0,NULL,NULL,NOW(),NULL,NOW(),NULL,NULL,1,1,'OVERRIDE',NULL,0,NULL,0,11,0,0,0,1,-1,'0',0)
 ,(2,1,'1',NULL,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,0,'PARENT',NULL,0,NULL,0,0,0,0,0,0,-1,'0',0)
 ,(5,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,5,'OVERRIDE','/login.php',0,NULL,0,0,0,1,0,1,-1,'0',0)
 ,(6,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,6,'OVERRIDE','/register.php',0,NULL,0,0,3,1,0,1,-1,'0',0)
 ,(7,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/profile/view.php',0,NULL,0,4,4,1,0,1,-1,'0',0)
 ,(8,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/profile/edit.php',0,NULL,0,0,0,7,0,1,-1,'0',0)
 ,(10,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/profile/avatar.php',0,NULL,0,0,1,7,0,1,-1,'0',0)
 ,(11,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/profile/messages.php',0,NULL,0,0,2,7,0,1,-1,'0',0)
 ,(12,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/profile/friends.php',0,NULL,0,0,3,7,0,1,-1,'0',0)
 ,(13,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/page_not_found.php',0,NULL,0,0,6,1,0,1,-1,'0',0)
 ,(14,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/page_forbidden.php',0,NULL,0,0,7,1,0,1,-1,'0',0)
 ,(15,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'OVERRIDE','/dashboard/view.php',0,NULL,0,9,8,1,0,0,-1,'0',0)
 ,(16,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/sitemap/view.php',0,NULL,0,4,1,15,0,0,-1,'0',0)
 ,(17,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/sitemap/full.php',0,NULL,0,0,0,16,0,0,-1,'0',0)
 ,(18,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/sitemap/explore.php',0,NULL,0,0,1,16,0,0,-1,'0',0)
 ,(19,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/sitemap/search.php',0,NULL,0,0,2,16,0,0,-1,'0',0)
 ,(20,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/sitemap/access.php',0,NULL,0,0,3,16,0,0,-1,'0',0)
 ,(21,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/files/view.php',0,NULL,0,4,2,15,0,0,-1,'0',0)
 ,(22,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/files/search.php',0,NULL,0,0,0,21,0,0,-1,'0',0)
 ,(23,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/files/attributes.php',0,NULL,0,0,1,21,0,0,-1,'0',0)
 ,(24,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/files/sets.php',0,NULL,0,0,2,21,0,0,-1,'0',0)
 ,(25,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/files/access.php',0,NULL,0,0,3,21,0,0,-1,'0',0)
 ,(26,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/reports.php',0,NULL,0,3,3,15,0,0,-1,'0',0)
 ,(27,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/reports/forms.php',0,NULL,0,0,0,26,0,0,-1,'0',0)
 ,(28,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/reports/surveys.php',0,NULL,0,0,1,26,0,0,-1,'0',0)
 ,(29,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/reports/logs.php',0,NULL,0,0,2,26,0,0,-1,'0',0)
 ,(30,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/users/view.php',0,NULL,0,5,4,15,0,0,-1,'0',0)
 ,(31,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/users/search.php',0,NULL,0,0,0,30,0,0,-1,'0',0)
 ,(32,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/users/add.php',0,NULL,0,0,1,30,0,0,-1,'0',0)
 ,(33,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/users/groups.php',0,NULL,0,0,2,30,0,0,-1,'0',0)
 ,(34,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/users/attributes.php',0,NULL,0,0,3,30,0,0,-1,'0',0)
 ,(35,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/users/registration.php',0,NULL,0,0,4,30,0,0,-1,'0',0)
 ,(36,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/scrapbook/view.php',0,NULL,0,0,5,15,0,0,-1,'0',0)
 ,(37,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/view.php',0,NULL,0,4,6,15,0,0,-1,'0',0)
 ,(38,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/themes/view.php',0,NULL,0,4,0,37,0,0,-1,'0',0)
 ,(39,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/themes/add.php',0,NULL,0,0,0,38,0,0,-1,'0',0)
 ,(40,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/themes/inspect.php',0,NULL,0,0,1,38,0,0,-1,'0',0)
 ,(41,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/themes/customize.php',0,NULL,0,0,2,38,0,0,-1,'0',0)
 ,(43,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/types/view.php',0,NULL,0,0,1,37,0,0,-1,'0',0)
 ,(44,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/attributes.php',0,NULL,0,0,2,37,0,0,-1,'0',0)
 ,(45,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/single.php',0,NULL,0,0,3,37,0,0,-1,'0',0)
 ,(46,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/install.php',0,NULL,0,0,7,15,0,0,-1,'0',0)
 ,(47,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/system/view.php',0,NULL,0,4,8,15,0,0,-1,'0',0)
 ,(48,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/system/jobs.php',0,NULL,0,0,0,47,0,0,-1,'0',0)
 ,(49,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/system/backup.php',0,NULL,0,0,1,47,0,0,-1,'0',0)
 ,(50,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/system/update.php',0,NULL,0,0,2,47,0,0,-1,'0',0)
 ,(51,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/system/notifications.php',0,NULL,0,0,3,47,0,0,-1,'0',0)
 ,(52,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/settings/view.php',0,NULL,0,2,9,15,0,0,-1,'0',0)
 ,(53,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/settings/mail/view.php',0,NULL,0,0,0,52,0,0,-1,'0',0)
 ,(54,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/settings/marketplace.php',0,NULL,0,0,1,52,0,0,-1,'0',0)
 ,(55,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/download_file.php',0,NULL,0,0,9,1,0,0,-1,'0',0)
 ,(64,2,'1',NULL,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,0,'PARENT',NULL,0,NULL,0,0,0,0,0,0,-1,'0',0)
 ,(65,3,'1',NULL,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,0,'PARENT',NULL,0,NULL,0,0,0,0,0,0,-1,'0',0)
 ,(66,4,'1',NULL,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,0,'PARENT',NULL,0,NULL,0,0,0,0,0,0,-1,'0',0)
 ,(67,2,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,1,5,1,0,1,-1,'0',0)
 ,(68,2,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,0,0,67,0,1,-1,'0',0)
 ,(69,2,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,1,1,1,0,1,-1,'0',0)
 ,(70,2,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,0,0,69,0,1,-1,'0',0)
 ,(71,1,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,2,2,1,0,1,-1,'0',0)
 ,(72,4,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,0,0,71,0,1,-1,'0',0)
 ,(73,4,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT',NULL,0,NULL,0,0,1,71,0,1,-1,'0',0)
 ,(74,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,1,'PARENT','/members.php',0,NULL,0,0,10,1,0,0,-1,'0',0)
 ,(75,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/composer/view.php',0,NULL,0,2,0,15,0,0,-1,'0',0)
 ,(76,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/composer/write.php',0,NULL,0,0,0,75,0,0,-1,'0',0)
 ,(77,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/composer/drafts.php',0,NULL,0,0,1,75,0,0,-1,'0',0)
 ,(78,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/pages/types/composer.php',0,NULL,0,0,1,43,0,0,-1,'0',0)
 ,(79,0,'0',1,0,NULL,NULL,NULL,NULL,NOW(),NULL,NULL,1,15,'PARENT','/dashboard/settings/multilingual/view.php',0,NULL,0,0,1,52,0,0,-1,'0',0);


INSERT INTO TaskPermissions VALUES(1,'access_task_permissions','タスク権限を変更します','',0)
,(2,'access_sitemap','サイトマップやページ検索へのアクセス権','',0)
,(3,'access_user_search','ユーザー検索へのアクセス権','',0)
,(4,'access_group_search','グループ検索へのアクセス権','',0)
,(5,'access_page_defaults','ページタイプのデフォルトブロックを変更できる','',0)
,(6,'backup','データベースバックアップが出来る','',0)
,(7,'sudo','他ユーザーとしてログインできる','',0)
,(8,'uninstall_packages','パッケージを削除出来る','',0)
,(9,'install_packages','マーケットプレイスへの接続とパッケージのインストールが出来る','',0)
,(10,'delete_user','ユーザーが削除出来る','',0);

INSERT INTO TaskPermissionUserGroups VALUES(1,3,0,1)
,(2,3,0,1)
,(3,3,0,1)
,(4,3,0,1)
,(5,3,0,1)
,(6,3,0,1)
,(8,3,0,1)
,(9,3,0,1)
,(10,3,0,1);

INSERT INTO atBoolean VALUES(14,0)
 ,(18,1)
 ,(23,0)
 ,(27,0)
 ,(31,0)
 ,(35,0)
 ,(39,0)
 ,(44,0);

INSERT INTO atBooleanSettings VALUES(12,1)
 ,(13,1);

INSERT INTO atDefault VALUES(11,'')
 ,(12,'')
 ,(13,'')
 ,(15,'')
 ,(16,'')
 ,(17,'')
 ,(20,'')
 ,(21,'')
 ,(22,'')
 ,(24,'')
 ,(25,'')
 ,(26,'')
 ,(28,'')
 ,(29,'')
 ,(30,'')
 ,(32,'')
 ,(33,'')
 ,(34,'')
 ,(36,'')
 ,(37,'')
 ,(38,'')
 ,(41,'')
 ,(42,'')
 ,(43,'');

INSERT INTO atNumber VALUES(1,800.0000)
 ,(2,192.0000)
 ,(3,800.0000)
 ,(4,192.0000)
 ,(5,800.0000)
 ,(6,192.0000)
 ,(7,800.0000)
 ,(8,215.0000)
 ,(9,800.0000)
 ,(10,192.0000);

INSERT INTO atSelectOptions VALUES(1,11,'sample',0,1)
 ,(2,11,'Hello World',1,1);

INSERT INTO atSelectOptionsSelected VALUES(40,1)
 ,(40,2)
 ,(45,1);

INSERT INTO atSelectSettings VALUES(11,1,'display_asc',1);

INSERT INTO btContentImage VALUES(8,4,0,0,0,'','')
 ,(11,2,0,0,0,'','')
 ,(13,1,0,0,0,'','');

INSERT INTO btContentLocal VALUES(4,'<h2>サイドバー</h2>\r\n<p>concrete5はすべての部分をカスタマイズ出来るCMSです。ここは、サイドバー・エリアで、メインエリアとは違うエリアです。移動モードにしドラックアンドドロップで自由に動かすことができます。</p>\r\n<p>&nbsp;</p>')
 ,(5,'<h1>オープンソース CMS - concrete5 にようこそ</h1>\r\n<p>concrete5は、WEBサイトを見たまま直接編集ができるコンテンツ・マネジメント・システムです。<a href=\"../index.php/login\" target=\"_blank\">ログイン</a>するとブロックと呼ばれるページの構成要素を変更したり追加できるようになります。</p>\r\n<p>以下が簡単な操作方法へのリンクです：</p>\r\n<ul>\r\n<li><a title=\"ログイン・編集の基本\" href=\"http://concrete5-japan.org/help/editing/login/\" target=\"_blank\">ページの編集方法</a></li>\r\n<li><a href=\"http://concrete5-japan.org/help/editing/add-a-page/\" target=\"_blank\">新規ページ作成方法</a></li>\r\n<li>いろいろな機能を持ったブロックを追加：<a href=\"http://www.youtube.com/watch?v=aZ6YfVvfybQ\" target=\"_blank\">フォーム</a></li>\r\n<li>テーマやアドオンを<a href=\"http://concrete5-japan.org/help/editing/install_theme_and_blocks/\" target=\"_blank\">マーケットプレイスから簡単自動インストール</a></li>\r\n</ul>\r\n<p>このサイトに、いろいろなサンプルをインストールしました。各ページへは 【<a title=\"管理画面\" href=\"{CCM:CID_15}\">管理画面</a>】- 【<a title=\"サイトマップ\" href=\"{CCM:CID_16}\">サイトマップ</a>】よりアクセスできます。いろいろなブロックを各ページで追加したり削除したりしてみてください。</p>\r\n<p>&nbsp;</p>')
 ,(15,'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum vel tellus lectus, scelerisque faucibus nunc. Curabitur lacus nibh, eleifend vel porttitor in, bibendum quis tortor. Curabitur eros ligula, scelerisque ac ultricies a, dictum ac tellus. Mauris id tellus tortor. Proin a sollicitudin libero. Nam pellentesque commodo magna, nec mattis elit pulvinar id. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Mauris orci dui, adipiscing sit amet bibendum vel, sodales sed purus. Donec fringilla odio vel enim cursus luctus quis semper leo. Donec rhoncus odio ac elit dignissim lobortis.</p>\r\n<p>&nbsp;</p>')
 ,(16,'<p>Duis dapibus nibh eu arcu viverra tempor. Fusce auctor sapien eu mauris malesuada vel euismod orci vulputate. Curabitur at orci id quam mollis rhoncus vitae volutpat urna. Nam eget sapien at neque mollis varius sed vitae ipsum. Vestibulum commodo, eros sit amet sagittis cursus, massa mi lacinia lorem, vel pellentesque sapien purus eu lacus. Pellentesque mollis gravida enim. Fusce mi odio, elementum ut fermentum a, pharetra in quam. Mauris sed vestibulum sapien. In sit amet faucibus diam. Proin lectus quam, sodales ut posuere non, viverra a nibh. Aenean sollicitudin, diam eu elementum rutrum, nisi ante pretium mi, ut tristique ante tellus non ligula. Nam diam turpis, viverra non volutpat vel, scelerisque vel neque. In pretium, libero et vulputate varius, libero nulla blandit ligula, tincidunt egestas leo mi eu nisi. Mauris nunc augue, cursus vel viverra non, feugiat in enim. In eget dignissim est. Donec dictum leo in libero tincidunt sollicitudin hendrerit elit placerat. Aliquam vitae nunc diam, non vulputate nibh. Quisque tincidunt, dui ut rutrum feugiat, libero lorem interdum sapien, eget pharetra mi ligula ut lectus. Pellentesque consequat mollis est viverra malesuada.</p>\r\n<p>Curabitur eget quam vitae tellus blandit congue a sed lectus. Nunc ultrices lacus dignissim felis venenatis varius placerat eros dapibus. Nulla facilisi. Vivamus sodales accumsan convallis. Mauris congue tempus feugiat. Proin elementum fringilla leo, sit amet pretium nisl imperdiet interdum. Suspendisse volutpat cursus eros, nec porta est laoreet at. Sed porttitor suscipit augue, eu molestie justo faucibus et. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Vivamus faucibus mi vel tortor consequat eget rutrum nisl ultrices. Praesent et lacinia augue. Phasellus id est id enim ultricies placerat. Etiam porta enim eu enim convallis sed eleifend metus faucibus. In ac lobortis eros. Pellentesque felis turpis, cursus sed imperdiet non, viverra vel diam. Donec vel orci mi, placerat egestas purus. Vestibulum vel diam id magna suscipit accumsan. Quisque risus felis, sagittis non iaculis id, tempus in arcu. Donec tempus metus neque. Proin malesuada dui a tortor pretium tincidunt quis at ligula.</p>\r\n<p>Nam laoreet faucibus purus ac pretium. Aenean euismod diam adipiscing erat semper quis sodales elit tristique. Vestibulum vel tellus eu lorem porttitor aliquet. Vestibulum bibendum viverra cursus. Aenean sit amet magna odio, convallis imperdiet metus. Duis condimentum posuere vulputate. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Sed vitae elit ut sapien vestibulum tempor sit amet ac tortor. Donec ligula nulla, varius id ornare id, vestibulum non felis. Nullam neque erat, tristique a eleifend pellentesque, eleifend sit amet ipsum. In eget urna nibh. Phasellus scelerisque, magna ac feugiat ultricies, risus dolor volutpat quam, in rutrum nunc ante id sem. Fusce interdum scelerisque fermentum.</p>\r\n<p>&nbsp;</p>')
 ,(21,'<h1>サイトマップ</h1>')
 ,(24,'<h1>concrete5についてもっと学ぼう！</h1>\r\n<p>concrete5 日本語公式サイトには、気軽に質問できる<a href=\"http://concrete5-japan.org/community/\" target=\"_blank\">コミュニティー</a>や<a href=\"http://concrete5-japan.org/community/forums/\" target=\"_blank\">フォーラム</a>、<a href=\"http://concrete5-japan.org/help/\" target=\"_blank\">ヘルプ</a>ページなどがあります。本家公式の<a href=\"http://www.concrete5.org/marketplace/\" target=\"_blank\">マーケットプレイス</a>では、<a href=\"http://www.concrete5.org/marketplace/addons/\" target=\"_blank\">拡張アドオン</a>や<a href=\"http://www.concrete5.org/marketplace/themes/\" target=\"_blank\">テーマ</a>などをダウンロードすることが出来ます。</p>')
 ,(25,'<h2>よくある質問</h2>\r\n<p>サイトヘッダー部分の<a href=\"http://concrete5-japan.org/help/faq/change-sitename/\" target=\"_blank\">サイト名の変更の仕方</a></p>\r\n<p>index.php を隠す<a href=\"http://concrete5-japan.org/help/faq/how_to_use_prettyurl/\" target=\"_blank\">プリティーURLの使い方</a></p>\r\n<p>サイトを引越ししたい方「<a href=\"http://concrete5-japan.org/help/install/how-to-restore/\" target=\"_blank\">復元（リストア）と引越の仕方</a>」</p>\r\n<p>テーマを作ったり、見栄えを変更する方法は「<a href=\"http://concrete5-japan.org/help/design/\" target=\"_blank\">テーマの仕組みとデザインの仕方</a>」</p>')
 ,(26,'<h1>コメントをどうぞ</h1>\r\n<p>ゲストブックブロックは、どのページにも追加できて簡単なコメントを残すことが出来る基本ブロックです。このページを「編集モード」にし、ゲストブロックを選択、メニューから編集をクリックして、設定できる各種項目を確認してみてください。</p>\r\n<p>また、マーケットプレイスには、掲示板機能を搭載した「<a title=\"Forums for concrete5\" href=\"http://www.concrete5.org/marketplace/addons/discussion/\" target=\"_blank\">Discussions Forum</a>」もあります。</p>\r\n<p>&nbsp;</p>')
 ,(31,'<p>ここが、ブログのイントロ部分です。もしも内容が短ければ、このエリアに全てを記入するとよいでしょう。この「Main」エリアにあるブロックは「<a title=\"ブログ\" href=\"{CCM:CID_71}\">ブログ</a>」ページでも表示されます。</p>')
 ,(32,'<p>ブログやホームページにあるように「もっと読む」リンクをクリックした時に、より詳しい情報を掲載したい場合は、この「Blog Post More」エリアにブロックを配置してください。このエリア部分は「<a title=\"ブログ\" href=\"{CCM:CID_71}\">ブログ</a>」ページには表示されません。</p>\r\n<p>「Main」エリアはイントロ部分だけを書いて、この「Blog Post More」エリアに詳細の情報等を書いたブロックを設置することにより、ユーザーが「もっと読む」リンクをクリックすると、投稿記事の詳細ページに遷移して、このエリアに配置されたブロックが表示されるようになります。</p>')
 ,(34,'<p>ここが、ブログのイントロ部分です。もしも内容が短ければ、このエリアに全てを記入するとよいでしょう。この「Main」エリアにあるブロックは「<a title=\"ブログ\" href=\"{CCM:CID_71}\">ブログ</a>」ページでも表示されます。</p>')
 ,(35,'<p>ブログやホームページにあるように「もっと読む」リンクをクリックした時に、より詳しい情報を掲載したい場合は、この「Blog Post More」エリアにブロックを配置してください。このエリア部分は「<a title=\"ブログ\" href=\"{CCM:CID_71}\">ブログ</a>」ページには表示されません。</p>\r\n<p>「Main」エリアはイントロ部分だけを書いて、この「Blog Post More」エリアに詳細の情報等を書いたブロックを設置することにより、ユーザーが「もっと読む」リンクをクリックすると、投稿記事の詳細ページに遷移して、このエリアに配置されたブロックが表示されるようになります。</p>')
 ,(36,'<p>ページを見たまま直接編集するのはいいですよね。</p>')
 ,(38,'<p>concrete5 日本語サイトの<a href=\"http://concrete5-japan.org/help/\" target=\"_blank\">ヘルプ</a>をご覧になりましたでしょうか？</p>\r\n<p>ある程度 concrete5 でのサイト運用にについて理解できたと思います。<br />新しいブログページを作る方法は、</p>\r\n<ol>\r\n<li><a title=\"ブログ\" href=\"{CCM:CID_71}\">ブログ</a>ページを訪れます。ここが、各ブログ投稿ページの親ページです</li>\r\n<li>ログインした状態で、画面左上の「新規ページ」ボタンを押します</li>\r\n<li>「ブログ記事」ページタイプを選択</li>\r\n<li>ページ名を入力し改行キー。もしくは、スクロールして「新規」ボタンをクリック。その他の項目は空白で構いません。後で編集モード時、ページ上部の「設定」ボタンより変更できます。</li>\r\n<li>すると、新しいブログ記事ページが出来上がります。ブロックを配置してページを完成させましょう</li>\r\n<li>「編集モード終了」ボタンを押し、ページを公開して、完成です。</li>\r\n</ol>')
 ,(41,'<p>{[CCM:SITE]}</p>');

INSERT INTO btDateNav VALUES(18,0,0,0,4,0,'current_page',0,0,0,0,0,0)
 ,(28,0,71,1,0,0,'current_month',0,0,0,0,0,0);

INSERT INTO btGuestBook VALUES(17,0,'コメント:','Y年m月d日',1,1,0,'')
 ,(27,0,'コメント:','Y年m月d日',1,1,0,'');

INSERT INTO btNavigation VALUES(1,'display_asc','top',0,0,'none','enough',0,0)
 ,(3,'display_asc','second_level',0,0,'relevant','enough',0,0)
 ,(7,'display_asc','top',0,0,'none','enough',0,0)
 ,(9,'display_asc','second_level',0,0,'relevant','enough',0,0)
 ,(10,'display_asc','top',0,0,'none','enough',0,0)
 ,(12,'display_asc','top',0,0,'none','enough',0,0)
 ,(14,'display_asc','top',0,0,'relevant_breadcrumb','enough',0,0)
 ,(20,'display_asc','top',0,0,'all','all',0,0);

INSERT INTO btNextPrevious VALUES(40,'next_previous','次','前',1,1,1,1,'display_asc');

INSERT INTO btPageList VALUES(30,10,'chrono_desc',0,0,1,1,4,1,'Blog','',0,0,0);

INSERT INTO btSearch VALUES(19,'検索結果','検索','','')
 ,(22,'サイトを検索','検索','','/search/search-results')
 ,(29,'タグ','','','/search/search-results');

INSERT INTO btSlideshow VALUES(2,0,'ORDER',NULL,NULL);

INSERT INTO btSlideshowImg VALUES(1,2,5,'',5,2,0,0,192)
 ,(2,2,4,'',5,2,0,1,215)
 ,(3,2,2,'',5,2,0,2,192)
 ,(4,2,3,'',5,2,0,3,192);

INSERT INTO btSurvey VALUES(37,'一番簡単なのは？',0);

INSERT INTO btSurveyOptions VALUES(1,37,'ページの修正',0)
 ,(2,37,'フォームを手軽に追加',1)
 ,(3,37,'レイアウトを気軽に追加',2);

INSERT INTO btTags VALUES(23,'Tags',68,'page',10)
 ,(33,'Tags',68,'page',10)
 ,(39,'Tags',68,'page',10);

INSERT INTO btYouTube VALUES(6,'20分で分かる concrete5 (Part 1)','http://www.youtube.com/watch?v=ioASHU8CaGI','','',0);

INSERT INTO CollectionSearchIndexAttributes VALUES(2,NULL,NULL,NULL,0,0,NULL,0,0,NULL)
 ,(1,NULL,NULL,NULL,0,0,NULL,0,0,NULL)
 ,(65,NULL,NULL,NULL,0,0,NULL,0,0,NULL)
 ,(42,NULL,NULL,NULL,0,0,NULL,0,0,NULL)
 ,(67,'','','',0,0,NULL,0,0,NULL)
 ,(68,'','','',1,0,NULL,0,0,NULL)
 ,(66,NULL,NULL,NULL,0,0,NULL,0,0,'\n')
 ,(69,'','','',0,0,NULL,0,0,NULL)
 ,(70,'','','',0,0,NULL,0,0,NULL)
 ,(71,'','','',0,0,NULL,0,0,NULL)
 ,(72,'','','',0,0,NULL,0,0,'\nsample\nHello World\n')
 ,(73,'','','',0,0,NULL,0,0,'\nsample\n');

INSERT INTO FileSearchIndexAttributes VALUES(1,800.0000,192.0000)
 ,(2,800.0000,192.0000)
 ,(3,800.0000,192.0000)
 ,(4,800.0000,215.0000)
 ,(5,800.0000,192.0000);
